#!/usr/bin/env python3
import click

from .. import __version__
from . import community, datanode_cli, evaluate, tool


@click.group()
@click.version_option(__version__)
def cli():
    """NLP Sandbox Client"""


def main():
    cli.add_command(community.cli)
    cli.add_command(evaluate.evaluate_prediction)
    cli.add_command(datanode_cli.cli)
    cli.add_command(tool.cli)
    cli()



"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.tool_type import ToolType


class TestToolType(unittest.TestCase):
    """ToolType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testToolType(self):
        """Test ToolType"""
        ToolType("type")


if __name__ == '__main__':
    unittest.main()



"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import unittest
from unittest.mock import patch

import nlpsandbox
from nlpsandbox.api.tool_api import ToolApi  # noqa: E501


class TestToolApi(unittest.TestCase):
    """ToolApi unit test stubs"""

    def setUp(self):
        self.api = ToolApi()  # noqa: E501
        self.patcher = patch('nlpsandbox.api_client.ApiClient.call_api')
        self.mock_foo = self.patcher.start()

    def tearDown(self):
        self.patcher.stop()

    def test_get_tool(self):
        """Test case for get_tool

        Get tool information  # noqa: E501
        """
        self.api.get_tool()

    def test_get_tool_dependencies(self):
        """Test case for get_tool_dependencies

        Get tool dependencies  # noqa: E501
        """
        self.api.get_tool_dependencies()


if __name__ == '__main__':
    unittest.main()



"""Test evaluation code"""
import math
import os

from nlpsandboxclient import evaluation

class TestEvaluation:
    """Test evaluation"""

    def setup_method(self):
        script_dir = os.path.dirname(os.path.realpath(__file__))
        self.pred_filepath = os.path.join(script_dir,
                                          "../data/prediction.json")
        self.gold_filepath = os.path.join(script_dir,
                                          "../data/goldstandard.json")

    def test_date(self):
        """Test date evaluation"""
        expected_results = {
            'date_location': [
                {'metric': 'F1', 'value': 0.75, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'precision', 'value': 0.75, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'recall', 'value': 0.75, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'F1', 'value': 0.5, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'precision', 'value': 0.5, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'recall', 'value': 0.5, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'F1', 'value': 0.67, 'type': 'token', 'mode': 'strict'},
                {'metric': 'precision', 'value': 0.6, 'type': 'token', 'mode': 'strict'},
                {'metric': 'recall', 'value': 0.75, 'type': 'token', 'mode': 'strict'}
            ],
            'date_type': [
                {'metric': 'F1', 'value': None},
                {'metric': 'precision', 'value': None},
                {'metric': 'recall', 'value': None}
            ]
        }
        date_evaluator = evaluation.DateEvaluation()
        date_evaluator.convert_dict(self.pred_filepath, self.gold_filepath)
        results = date_evaluator.eval()
        for date_type in results['date_type']:
            if math.isnan(date_type['value']):
                date_type['value'] = None
        assert results == expected_results

    def test_person(self):
        """Test person evaluation"""
        expected_results = {
            'person_location': [
                {'metric': 'F1', 'value': 0.5, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'precision', 'value': 0.5, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'recall', 'value': 0.5, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'F1', 'value': 0.5, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'precision', 'value': 0.5, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'recall', 'value': 0.5, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'F1', 'value': 0.77, 'type': 'token', 'mode': 'strict'},
                {'metric': 'precision', 'value': 0.83, 'type': 'token', 'mode': 'strict'},
                {'metric': 'recall', 'value': 0.71, 'type': 'token', 'mode': 'strict'}
            ],
            'person_type': [
                {'metric': 'F1', 'value': None},
                {'metric': 'precision', 'value': None},
                {'metric': 'recall', 'value': None}
            ]
        }
        evaluator = evaluation.PersonNameEvaluation()
        evaluator.convert_dict(self.pred_filepath, self.gold_filepath)
        results = evaluator.eval()
        for person_type in results['person_type']:
            if math.isnan(person_type['value']):
                person_type['value'] = None
        assert results == expected_results

    def test_address(self):
        """Test person evaluation"""
        expected_results = {
            'address_location': [
                {'metric': 'F1', 'value': 0.75, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'precision', 'value': 0.75, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'recall', 'value': 0.75, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'F1', 'value': 0.5, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'precision', 'value': 0.5, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'recall', 'value': 0.5, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'F1', 'value': 0.67, 'type': 'token', 'mode': 'strict'},
                {'metric': 'precision', 'value': 0.75, 'type': 'token', 'mode': 'strict'},
                {'metric': 'recall', 'value': 0.6, 'type': 'token', 'mode': 'strict'}
            ],
            'address_type': [
                {'metric': 'F1', 'value': 0.5},
                {'metric': 'precision', 'value': 0.5},
                {'metric': 'recall', 'value': 0.5}
            ]
        }
        evaluator = evaluation.PhysicalAddressEvaluation()
        evaluator.convert_dict(self.pred_filepath, self.gold_filepath)
        results = evaluator.eval()
        assert results == expected_results


    def test_id(self):
        """Test id evaluation"""
        expected_results = {
            'id_location': [
                {'metric': 'F1', 'value': 1, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'precision', 'value': 1, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'recall', 'value': 1, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'F1', 'value': 1, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'precision', 'value': 1, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'recall', 'value': 1, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'F1', 'value': 1, 'type': 'token', 'mode': 'strict'},
                {'metric': 'precision', 'value': 1, 'type': 'token', 'mode': 'strict'},
                {'metric': 'recall', 'value': 1, 'type': 'token', 'mode': 'strict'}
            ],
            'id_type': [
                {'metric': 'F1', 'value': 1},
                {'metric': 'precision', 'value': 1},
                {'metric': 'recall', 'value': 1}
            ]
        }
        evaluator = evaluation.IdEvaluation()
        evaluator.convert_dict(self.pred_filepath, self.gold_filepath)
        results = evaluator.eval()
        for id_type in results['id_type']:
            if math.isnan(id_type['value']):
                id_type['value'] = None
        assert results == expected_results


    def test_contact(self):
        """Test contact evaluation"""
        expected_results = {
            'contact_location': [
                {'metric': 'F1', 'value': 1, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'precision', 'value': 1, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'recall', 'value': 1, 'type': 'instance', 'mode': 'relax'},
                {'metric': 'F1', 'value': 1, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'precision', 'value': 1, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'recall', 'value': 1, 'type': 'instance', 'mode': 'strict'},
                {'metric': 'F1', 'value': 1, 'type': 'token', 'mode': 'strict'},
                {'metric': 'precision', 'value': 1, 'type': 'token', 'mode': 'strict'},
                {'metric': 'recall', 'value': 1, 'type': 'token', 'mode': 'strict'}
            ],
            'contact_type': [
                {'metric': 'F1', 'value': 1},
                {'metric': 'precision', 'value': 1},
                {'metric': 'recall', 'value': 1}
            ]
        }
        evaluator = evaluation.ContactEvaluation()
        evaluator.convert_dict(self.pred_filepath, self.gold_filepath)
        results = evaluator.eval()
        for contact_type in results['contact_type']:
            if math.isnan(contact_type['value']):
                contact_type['value'] = None
        assert results == expected_results


"""
    NLP Sandbox Data Node API

    # Overview  The NLP Sandbox Data Node is a repository of data used to benchmark NLP Tools like the NLP Sandbox Date Annotator and Person Name Annotator.  The resources that can be stored in this Data Node and the operations supported are listed below:  - Create and manage datasets - Create and manage FHIR stores   - Store and retrieve FHIR patient profiles   - Store and retrieve clinical   notes - Create and manage annotation stores   - Store and retrieve text annotations   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import unittest
from unittest.mock import patch

import nlpsandbox
from nlpsandbox.api.dataset_api import DatasetApi  # noqa: E501


class TestDatasetApi(unittest.TestCase):
    """DatasetApi unit test stubs"""

    def setUp(self):
        self.api = DatasetApi()  # noqa: E501
        self.patcher = patch('nlpsandbox.api_client.ApiClient.call_api')
        self.mock_foo = self.patcher.start()

    def tearDown(self):
        self.patcher.stop()

    def test_create_dataset(self):
        """Test case for create_dataset

        Create a dataset  # noqa: E501
        """
        self.api.create_dataset(
            dataset_id="foo",
            body={}
        )

    def test_delete_dataset(self):
        """Test case for delete_dataset

        Delete a dataset by ID  # noqa: E501
        """
        self.api.delete_dataset(
            dataset_id="foo"
        )

    def test_get_dataset(self):
        """Test case for get_dataset

        Get a dataset by ID  # noqa: E501
        """
        self.api.get_dataset(
            dataset_id="foo"
        )

    def test_list_datasets(self):
        """Test case for list_datasets

        Get all datasets  # noqa: E501
        """
        self.api.list_datasets()


if __name__ == '__main__':
    unittest.main()




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.annotation_api import AnnotationApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from nlpsandbox.api.annotation_api import AnnotationApi
from nlpsandbox.api.annotation_store_api import AnnotationStoreApi
from nlpsandbox.api.dataset_api import DatasetApi
from nlpsandbox.api.deidentified_note_api import DeidentifiedNoteApi
from nlpsandbox.api.fhir_store_api import FhirStoreApi
from nlpsandbox.api.health_check_api import HealthCheckApi
from nlpsandbox.api.note_api import NoteApi
from nlpsandbox.api.patient_api import PatientApi
from nlpsandbox.api.text_contact_annotation_api import TextContactAnnotationApi
from nlpsandbox.api.text_covid_symptom_annotation_api import TextCovidSymptomAnnotationApi
from nlpsandbox.api.text_date_annotation_api import TextDateAnnotationApi
from nlpsandbox.api.text_id_annotation_api import TextIdAnnotationApi
from nlpsandbox.api.text_person_name_annotation_api import TextPersonNameAnnotationApi
from nlpsandbox.api.text_physical_address_annotation_api import TextPhysicalAddressAnnotationApi
from nlpsandbox.api.tool_api import ToolApi



"""
    NLP Sandbox API

    NLP Sandbox REST API  # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: team@nlpsandbox.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.deidentification_step import DeidentificationStep
from nlpsandbox.model.note import Note
globals()['DeidentificationStep'] = DeidentificationStep
globals()['Note'] = Note
from nlpsandbox.model.deidentify_request import DeidentifyRequest


class TestDeidentifyRequest(unittest.TestCase):
    """DeidentifyRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDeidentifyRequest(self):
        """Test DeidentifyRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DeidentifyRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python3
# Author: Yao Yan
# Description: This script is used to evaluate the annotation by participants
# with gold standards, we will conduct the evaluation based on subcategory:
# date, person name,physical address

from abc import ABCMeta
import json
import os
import re


# take as input the location of
class Evaluation(metaclass=ABCMeta):
    """Evaluate the different types"""
    evaluation_type = None
    annotation = None
    col = None
    post_path = None

    def __init__(self):
        self.gs_dict_seq = dict()
        self.sys_dict_seq = dict()
        self.gs_dict_token = dict()
        self.sys_dict_token = dict()
        self.loc_list = list()
        self.type_list = list()
        # noAddressType to check if participants' submission include "addressType", default is True, no addressType
        self.noAddressType = True
        if self.evaluation_type is None:
            raise ValueError("Must specify evaluation_type attribute")

    def convert_annotations(self, annotations):
        all_annotations = []
        for annotation in annotations:
            # print(annotation)
            noteid = annotation['annotationSource']['resourceSource']['name']
            for annots in annotation[self.post_path]:
                annots['noteId'] = os.path.basename(noteid)
                all_annotations.append(annots)

        new_annotations = {self.col: all_annotations}
        return new_annotations

    def convert_dict(self, sys_file, gs_file):
        with open(gs_file) as f:
            gs = json.load(f)
            gs = self.convert_annotations(gs)
            gs = gs[self.col]
        with open(sys_file) as f:
            sys = json.load(f)
            sys = self.convert_annotations(sys)
            sys = sys[self.col]

        self.sys_dict_seq = self.json_dict_seq(sys)
        self.gs_dict_seq = self.json_dict_seq(gs)
        self.sys_dict_token = self.json_dict_token(sys)
        self.gs_dict_token = self.json_dict_token(gs)

    # load the json file and convert it to a untokenised dictionary
    # with key 'noteId-start-length'
    # with value ["text"(untokened),"dateFormat"]
    def json_dict_seq(self, input):
        json_dict = {}
        for anno in input:
            noteId = anno['noteId']
            start = anno['start']
            data_loc = '{}-{}'.format(noteId, start)
            text = anno['text']
            length = anno['length']
            # dateFormat, personType, addressType
            annotation_format = anno.get(self.annotation, float('nan'))
            date_list = [text, annotation_format, length]
            json_dict[data_loc] = date_list
        return json_dict

    # load the json file and convert it to a untokenised dictionary
    # with key 'noteId-start-length'
    # with value ["text"(untokened),"dateFormat","length"]

    def json_dict_token(self, input):
        json_dict = {}
        for anno in input:
            noteId = anno['noteId']
            start = anno['start']
            text = anno['text']
            # dateFormat, personType, addressType
            # is self.annotation(dateFormat, personType, addressType) not in the
            # JSON file, use float('nan')
            annotation_format = anno.get(self.annotation, float('nan'))
            sub_text = re.split(r'\s+', text)
            for sub in sub_text:
                leng = len(sub)
                data_loc = '{}-{}-{}'.format(noteId, start, leng)
                start = start + leng + 1
                # [text, dateFormat,length]
                date_list = [sub, annotation_format, leng]
                json_dict[data_loc] = date_list
        return json_dict

    def eval(self):
        self.eval_category_instance()
        self.eval_category_token()
        final_address_eval = dict()
        final_address_eval[f"{self.evaluation_type}_location"] = self.loc_list
        final_address_eval[f"{self.evaluation_type}_type"] = self.type_list
        # print(final_address_eval)
        # expected json object for date
        # address_loc={
        #       "metric": “F1”/“precision”/“recall”,
        #       "value" (double): 0.89,
        #       "type":  “instance”/“token”
        #       "mode": “strict”/“relax”
        #       }
        # address_type={
        #       "metric": “F1”/“precision”/“recall”,
        #       "value" (double): 0.89
        #       }

        # calculate true positive

        # instance based_eval
        return final_address_eval

    # strict: length match, relax: length match +/- 2
    def eval_category_instance(self):
        sys_dict = self.sys_dict_seq
        gs_dict = self.gs_dict_seq
        tp = 0
        fp = 0
        fn = 0
        for key in sys_dict.keys():
            if key in gs_dict.keys() and self.relax_cond(key, sys_dict, gs_dict):
                tp = tp + 1
            else:
                fp = fp + 1
        for key in gs_dict.keys():
            if key not in sys_dict.keys() or \
                    (key in sys_dict.keys() and not self.relax_cond(key, sys_dict, gs_dict)):
                fn = fn + 1
        self.print_out(tp, fp, fn, "instance", "relax")
        # strict
        tp = 0
        fp = 0
        fn = 0
        for key in sys_dict.keys():
            if key in gs_dict.keys() and self.strict_cond(key, sys_dict, gs_dict):
                tp = tp + 1
            else:
                fp = fp + 1
        for key in gs_dict.keys():
            if (key not in sys_dict.keys())\
                    or (key in sys_dict.keys() and not self.strict_cond(key, sys_dict, gs_dict)):
                fn = fn + 1
        self.print_out(tp, fp, fn, "instance", "strict")
        # data format, instance
        tp = 0
        fp = 0
        fn = 0
        for key in sys_dict.keys():
            if type(sys_dict[key][1]) == str and len(sys_dict[key][1]) != 0:
                self.noAddressType = False
            if key in gs_dict.keys() and self.format_cond(key, sys_dict, gs_dict):
                tp = tp + 1
            else:
                fp = fp + 1
        for key in gs_dict.keys():
            if key not in sys_dict.keys() or \
                    (key in sys_dict.keys() and not self.format_cond(key, sys_dict, gs_dict)):
                fn = fn + 1
        self.print_out(tp, fp, fn, self.evaluation_type, "strict")
        self.noAddressType = True

    def relax_cond(self, key, sys_dict, gs_dict):
        return abs(sys_dict[key][2]-gs_dict[key][2]) <= 2

    def strict_cond(self, key, sys_dict, gs_dict):
        return abs(sys_dict[key][2]-gs_dict[key][2]) == 0

    def format_cond(self, key, sys_dict, gs_dict):
        return (sys_dict[key][1] == gs_dict[key][1]) and abs(sys_dict[key][2] - gs_dict[key][2]) == 0

    def eval_category_token(self):
        # relax
        sys_dict = self.sys_dict_token
        gs_dict = self.gs_dict_token
        tp = 0
        fp = 0
        fn = 0
        for key in sys_dict.keys():
            if key in gs_dict.keys() and self.strict_cond(key, sys_dict, gs_dict):
                tp = tp + 1
            else:
                fp = fp + 1
        for key in gs_dict.keys():
            if key not in sys_dict.keys() or \
                    (key in sys_dict.keys() and not self.strict_cond(key, sys_dict, gs_dict)):
                fn = fn + 1
        self.print_out(tp, fp, fn, "token", "strict")

    def print_out(self, tp, fp, fn, type_up, type_lower):
        if (type_up == "date" or type_up == "person") or \
         (type_up == "address" and self.noAddressType is True):
            precision = float('nan')
            recall = float('nan')
            F1 = float('nan')
        else:
            # precision (P): TP / (TP + FP)
            # Recall (R): TP / (TP + FN)
            # F1 score: 2 * ((P * R) / (P + R))
            if tp + fp == 0:
                precision = 0
            else:
                precision = round(tp / (tp + fp), 2)
            if tp + fn == 0:
                recall = 0
            else:
                recall = round(tp / (tp + fn), 2)
            if precision + recall == 0:
                F1 = 0
            else:
                F1 = round(2 * ((precision * recall) / (precision + recall)), 2)
        # print("F1 {}".format(F1))
        # print(type_up,type_lower)
        # print("tp: {},fp: {},fn: {}".format(tp,fp,fn))
        str_fmt = "{:<25}{:<15}{:<15}{:<20}"

        print(str_fmt.format(type_up, "F1", "Precision", "Recall"))

        print("{:-<25}{:-<15}{:-<15}{:-<20}".format("", "", "", ""))

        print(str_fmt.format(type_lower, F1,
                             precision,
                             recall))

        print("\n")
        eval_dict = {"F1": F1, "precision": precision, "recall": recall}
        # loc_map = dict()
        # type_map = dict()
        if type_up != self.evaluation_type:
            for key in eval_dict.keys():
                loc_map = {"metric": key,
                           "value": eval_dict[key],
                           "type": type_up,
                           "mode": type_lower}
                self.loc_list.append(loc_map)
        else:
            for key in eval_dict.keys():
                type_map = {"metric": key,
                            "value": eval_dict[key]}
                self.type_list.append(type_map)


class DateEvaluation(Evaluation):
    evaluation_type = "date"
    annotation = "dateFormat"
    col = "date_annotations"
    post_path = "textDateAnnotations"


class PersonNameEvaluation(Evaluation):
    evaluation_type = "person"
    annotation = "personType"
    col = "person_name_annotations"
    post_path = "textPersonNameAnnotations"


class PhysicalAddressEvaluation(Evaluation):
    evaluation_type = "address"
    annotation = "addressType"
    col = "physical_location_annotations"
    post_path = "textPhysicalAddressAnnotations"


class IdEvaluation(Evaluation):
    evaluation_type = "id"
    annotation = "idType"
    col = "id_annotations"
    post_path = "textIdAnnotations"


class ContactEvaluation(Evaluation):
    evaluation_type = "contact"
    annotation = "contactType"
    col = "contact_annotations"
    post_path = "textContactAnnotations"



"""
    NLP Sandbox Data Node API

    # Overview  The NLP Sandbox Data Node is a repository of data used to benchmark NLP Tools like the NLP Sandbox Date Annotator and Person Name Annotator.  The resources that can be stored in this Data Node and the operations supported are listed below:  - Create and manage datasets - Create and manage FHIR stores   - Store and retrieve FHIR patient profiles   - Store and retrieve clinical   notes - Create and manage annotation stores   - Store and retrieve text annotations   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import unittest
from unittest.mock import patch

import nlpsandbox
from nlpsandbox.api.note_api import NoteApi  # noqa: E501


class TestNoteApi(unittest.TestCase):
    """NoteApi unit test stubs"""

    def setUp(self):
        self.api = NoteApi()  # noqa: E501
        self.patcher = patch('nlpsandbox.api_client.ApiClient.call_api')
        self.mock_foo = self.patcher.start()

    def tearDown(self):
        self.patcher.stop()

    def test_create_note(self):
        """Test case for create_note

        Create a note  # noqa: E501
        """
        self.api.create_note(
            dataset_id="awesome-dataset",
            fhir_store_id="awesome-fhir-store",
            note_id="awesome-note",
            note_create_request={
                "text": "texting foo",
                "type": "loinc:LP29684-5",
                "patient_id": "awesome-patient"
            }
        )

    def test_delete_note(self):
        """Test case for delete_note

        Delete a note  # noqa: E501
        """
        self.api.delete_note(
            dataset_id="awesome-dataset",
            fhir_store_id="awesome-fhir-store",
            note_id="awesome-note"
        )

    def test_get_note(self):
        """Test case for get_note

        Get a note  # noqa: E501
        """
        self.api.get_note(
            dataset_id="awesome-dataset",
            fhir_store_id="awesome-fhir-store",
            note_id="awesome-note"
        )

    def test_list_notes(self):
        """Test case for list_notes

        List notes  # noqa: E501
        """
        self.api.list_notes(
            dataset_id="awesome-dataset",
            fhir_store_id="awesome-fhir-store"
        )


if __name__ == '__main__':
    unittest.main()



"""
    NLP Sandbox API

    NLP Sandbox REST API  # noqa: E501

    The version of the OpenAPI document: 1.1.2
    Contact: team@nlpsandbox.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from nlpsandbox.api_client import ApiClient, Endpoint as _Endpoint
from nlpsandbox.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from nlpsandbox.model.annotation import Annotation
from nlpsandbox.model.annotation_create_request import AnnotationCreateRequest
from nlpsandbox.model.annotation_create_response import AnnotationCreateResponse
from nlpsandbox.model.annotation_id import AnnotationId
from nlpsandbox.model.annotation_store_id import AnnotationStoreId
from nlpsandbox.model.dataset_id import DatasetId
from nlpsandbox.model.error import Error
from nlpsandbox.model.fhir_store_id import FhirStoreId
from nlpsandbox.model.page_limit import PageLimit
from nlpsandbox.model.page_of_annotations import PageOfAnnotations
from nlpsandbox.model.page_offset import PageOffset


class AnnotationApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __create_annotation(
            self,
            dataset_id,
            annotation_store_id,
            annotation_id,
            **kwargs
        ):
            """Create an annotation  # noqa: E501

            Create an annotation  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_annotation(dataset_id, annotation_store_id, annotation_id, async_req=True)
            >>> result = thread.get()

            Args:
                dataset_id (DatasetId): The ID of the dataset
                annotation_store_id (AnnotationStoreId): The ID of the annotation store
                annotation_id (AnnotationId): The ID of the annotation that is being created

            Keyword Args:
                annotation_create_request (AnnotationCreateRequest): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                AnnotationCreateResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['dataset_id'] = \
                dataset_id
            kwargs['annotation_store_id'] = \
                annotation_store_id
            kwargs['annotation_id'] = \
                annotation_id
            return self.call_with_http_info(**kwargs)

        self.create_annotation = _Endpoint(
            settings={
                'response_type': (AnnotationCreateResponse,),
                'auth': [],
                'endpoint_path': '/datasets/{datasetId}/annotationStores/{annotationStoreId}/annotations',
                'operation_id': 'create_annotation',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'dataset_id',
                    'annotation_store_id',
                    'annotation_id',
                    'annotation_create_request',
                ],
                'required': [
                    'dataset_id',
                    'annotation_store_id',
                    'annotation_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'dataset_id':
                        (DatasetId,),
                    'annotation_store_id':
                        (AnnotationStoreId,),
                    'annotation_id':
                        (AnnotationId,),
                    'annotation_create_request':
                        (AnnotationCreateRequest,),
                },
                'attribute_map': {
                    'dataset_id': 'datasetId',
                    'annotation_store_id': 'annotationStoreId',
                    'annotation_id': 'annotationId',
                },
                'location_map': {
                    'dataset_id': 'path',
                    'annotation_store_id': 'path',
                    'annotation_id': 'query',
                    'annotation_create_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_annotation
        )

        def __delete_annotation(
            self,
            dataset_id,
            annotation_store_id,
            annotation_id,
            **kwargs
        ):
            """Delete an annotation  # noqa: E501

            Deletes the annotation specified  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_annotation(dataset_id, annotation_store_id, annotation_id, async_req=True)
            >>> result = thread.get()

            Args:
                dataset_id (DatasetId): The ID of the dataset
                annotation_store_id (FhirStoreId): The ID of the annotation store
                annotation_id (AnnotationId): The ID of the annotation

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['dataset_id'] = \
                dataset_id
            kwargs['annotation_store_id'] = \
                annotation_store_id
            kwargs['annotation_id'] = \
                annotation_id
            return self.call_with_http_info(**kwargs)

        self.delete_annotation = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/datasets/{datasetId}/annotationStores/{annotationStoreId}/annotations/{annotationId}',
                'operation_id': 'delete_annotation',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'dataset_id',
                    'annotation_store_id',
                    'annotation_id',
                ],
                'required': [
                    'dataset_id',
                    'annotation_store_id',
                    'annotation_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'dataset_id':
                        (DatasetId,),
                    'annotation_store_id':
                        (FhirStoreId,),
                    'annotation_id':
                        (AnnotationId,),
                },
                'attribute_map': {
                    'dataset_id': 'datasetId',
                    'annotation_store_id': 'annotationStoreId',
                    'annotation_id': 'annotationId',
                },
                'location_map': {
                    'dataset_id': 'path',
                    'annotation_store_id': 'path',
                    'annotation_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__delete_annotation
        )

        def __get_annotation(
            self,
            dataset_id,
            annotation_store_id,
            annotation_id,
            **kwargs
        ):
            """Get an annotation  # noqa: E501

            Returns the annotation specified  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_annotation(dataset_id, annotation_store_id, annotation_id, async_req=True)
            >>> result = thread.get()

            Args:
                dataset_id (DatasetId): The ID of the dataset
                annotation_store_id (FhirStoreId): The ID of the annotation store
                annotation_id (AnnotationId): The ID of the annotation

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                Annotation
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['dataset_id'] = \
                dataset_id
            kwargs['annotation_store_id'] = \
                annotation_store_id
            kwargs['annotation_id'] = \
                annotation_id
            return self.call_with_http_info(**kwargs)

        self.get_annotation = _Endpoint(
            settings={
                'response_type': (Annotation,),
                'auth': [],
                'endpoint_path': '/datasets/{datasetId}/annotationStores/{annotationStoreId}/annotations/{annotationId}',
                'operation_id': 'get_annotation',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'dataset_id',
                    'annotation_store_id',
                    'annotation_id',
                ],
                'required': [
                    'dataset_id',
                    'annotation_store_id',
                    'annotation_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'dataset_id':
                        (DatasetId,),
                    'annotation_store_id':
                        (FhirStoreId,),
                    'annotation_id':
                        (AnnotationId,),
                },
                'attribute_map': {
                    'dataset_id': 'datasetId',
                    'annotation_store_id': 'annotationStoreId',
                    'annotation_id': 'annotationId',
                },
                'location_map': {
                    'dataset_id': 'path',
                    'annotation_store_id': 'path',
                    'annotation_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_annotation
        )

        def __list_annotations(
            self,
            dataset_id,
            annotation_store_id,
            **kwargs
        ):
            """List the annotations in an annotation store  # noqa: E501

            Returns the annotations in an annotation store  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_annotations(dataset_id, annotation_store_id, async_req=True)
            >>> result = thread.get()

            Args:
                dataset_id (DatasetId): The ID of the dataset
                annotation_store_id (AnnotationStoreId): The ID of the annotation store

            Keyword Args:
                limit (PageLimit): Maximum number of results returned. [optional]
                offset (PageOffset): Index of the first result that must be returned. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                PageOfAnnotations
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['dataset_id'] = \
                dataset_id
            kwargs['annotation_store_id'] = \
                annotation_store_id
            return self.call_with_http_info(**kwargs)

        self.list_annotations = _Endpoint(
            settings={
                'response_type': (PageOfAnnotations,),
                'auth': [],
                'endpoint_path': '/datasets/{datasetId}/annotationStores/{annotationStoreId}/annotations',
                'operation_id': 'list_annotations',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'dataset_id',
                    'annotation_store_id',
                    'limit',
                    'offset',
                ],
                'required': [
                    'dataset_id',
                    'annotation_store_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'dataset_id':
                        (DatasetId,),
                    'annotation_store_id':
                        (AnnotationStoreId,),
                    'limit':
                        (PageLimit,),
                    'offset':
                        (PageOffset,),
                },
                'attribute_map': {
                    'dataset_id': 'datasetId',
                    'annotation_store_id': 'annotationStoreId',
                    'limit': 'limit',
                    'offset': 'offset',
                },
                'location_map': {
                    'dataset_id': 'path',
                    'annotation_store_id': 'path',
                    'limit': 'query',
                    'offset': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_annotations
        )



"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import unittest

import nlpsandbox
from nlpsandbox.api.text_contact_annotation_api import TextContactAnnotationApi  # noqa: E501


class TestTextContactAnnotationApi(unittest.TestCase):
    """TextContactAnnotationApi unit test stubs"""

    def setUp(self):
        self.api = TextContactAnnotationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_text_contact_annotations(self):
        """Test case for create_text_contact_annotations

        Annotate contact information in a clinical note  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.text_physical_address_annotation import TextPhysicalAddressAnnotation
globals()['TextPhysicalAddressAnnotation'] = TextPhysicalAddressAnnotation
from nlpsandbox.model.text_physical_address_annotation_response import TextPhysicalAddressAnnotationResponse


class TestTextPhysicalAddressAnnotationResponse(unittest.TestCase):
    """TextPhysicalAddressAnnotationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTextPhysicalAddressAnnotationResponse(self):
        """Test TextPhysicalAddressAnnotationResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TextPhysicalAddressAnnotationResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import unittest
from unittest.mock import patch

import nlpsandbox
from nlpsandbox.api.text_physical_address_annotation_api import TextPhysicalAddressAnnotationApi  # noqa: E501


class TestTextPhysicalAddressAnnotationApi(unittest.TestCase):
    """TextPhysicalAddressAnnotationApi unit test stubs"""

    def setUp(self):
        self.api = TextPhysicalAddressAnnotationApi()  # noqa: E501
        self.patcher = patch('nlpsandbox.api_client.ApiClient.call_api')
        self.mock_foo = self.patcher.start()

    def tearDown(self):
        self.patcher.stop()

    def test_create_text_physical_address_annotations(self):
        """Test case for create_text_physical_address_annotations

        Annotate physical addresses in a clinical note  # noqa: E501
        """
        self.api.create_text_physical_address_annotations(
            text_physical_address_annotation_request={
                "note": {
                    "identifier": "note-1",
                    "type": "note-type",
                    "text": "my text here",
                    "patient_id": "patient-1"
                }
            }
        )


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python3
import json

import click
from nlpsandboxclient import client, utils


@click.group(name='tool', no_args_is_help=True)
def cli():
    """Commands to interact with NLP Tools."""


@cli.command(no_args_is_help=True)
@click.option('--annotator_host', help='Annotator host.', required=True)
@click.option('--note_json', help='Clinical notes json',
              type=click.Path(exists=True), required=True)
@click.option('--output', help='Specify output json path',
              type=click.Path())
@click.option('--tool_type', help='The type of tool.',
              type=click.Choice(['nlpsandbox:date-annotator',
                                 'nlpsandbox:person-name-annotator',
                                 'nlpsandbox:physical-address-annotator',
                                 'nlpsandbox:contact-annotator',
                                 'nlpsandbox:id-annotator',
                                 'nlpsandbox:covid-symptom-annotator'],
                                case_sensitive=False), required=True)
def annotate_note(annotator_host, note_json, output, tool_type):
    """Annotate a note with specified annotator"""
    with open(note_json, "r") as note_f:
        notes = json.load(note_f)
    all_annotations = []
    for note in notes:
        note_name = note.pop("note_name")
        annotations = client.annotate_note(host=annotator_host, note=note,
                                           tool_type=tool_type)
        annotations['annotationSource'] = {
            "resourceSource": {
                "name": note_name
            }
        }
        all_annotations.append(annotations)
    utils.stdout_or_json(all_annotations, output)


@cli.command(no_args_is_help=True)
@click.option('--annotator_host', help='Annotator host', required=True)
@click.option('--output', help='Specify output json path',
              type=click.Path())
def get_tool(annotator_host, output):
    """Get tool information"""
    tool = client.get_tool(host=annotator_host)
    utils.stdout_or_json(tool.to_dict(), output)


@cli.command(no_args_is_help=True)
@click.option('--url', help='The url to check', required=True)
def check_url(url):
    """Checks if URL is implemented"""
    utils.check_url(url=url)


if __name__ == '__main__':
    cli()



"""
    NLP Sandbox Data Node API

    # Overview  The NLP Sandbox Data Node is a repository of data used to benchmark NLP Tools like the NLP Sandbox Date Annotator and Person Name Annotator.  The resources that can be stored in this Data Node and the operations supported are listed below:  - Create and manage datasets - Create and manage FHIR stores   - Store and retrieve FHIR patient profiles   - Store and retrieve clinical   notes - Create and manage annotation stores   - Store and retrieve text annotations   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import unittest
from unittest.mock import patch

import nlpsandbox
from nlpsandbox.api.fhir_store_api import FhirStoreApi  # noqa: E501


class TestFhirStoreApi(unittest.TestCase):
    """FhirStoreApi unit test stubs"""

    def setUp(self):
        self.api = FhirStoreApi()  # noqa: E501
        self.patcher = patch('nlpsandbox.api_client.ApiClient.call_api')
        self.mock_foo = self.patcher.start()

    def tearDown(self):
        self.patcher.stop()

    def test_create_fhir_store(self):
        """Test case for create_fhir_store

        Create a FHIR store  # noqa: E501
        """
        self.api.create_fhir_store(
            dataset_id="awesome-dataset",
            fhir_store_id="awesome-fhir-store",
            body={}
        )

    def test_delete_fhir_store(self):
        """Test case for delete_fhir_store

        Delete a FHIR store  # noqa: E501
        """
        self.api.delete_fhir_store(
            dataset_id="awesome-dataset",
            fhir_store_id="awesome-fhir-store",
        )

    def test_get_fhir_store(self):
        """Test case for get_fhir_store

        Get a FHIR store  # noqa: E501
        """
        self.api.get_fhir_store(
            dataset_id="awesome-dataset",
            fhir_store_id="awesome-fhir-store",
        )

    def test_list_fhir_stores(self):
        """Test case for list_fhir_stores

        List the FHIR stores in a dataset  # noqa: E501
        """
        self.api.list_fhir_stores(dataset_id="awesome-dataset")


if __name__ == '__main__':
    unittest.main()



"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.text_person_name_annotation import TextPersonNameAnnotation
globals()['TextPersonNameAnnotation'] = TextPersonNameAnnotation
from nlpsandbox.model.text_person_name_annotation_response import TextPersonNameAnnotationResponse


class TestTextPersonNameAnnotationResponse(unittest.TestCase):
    """TextPersonNameAnnotationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTextPersonNameAnnotationResponse(self):
        """Test TextPersonNameAnnotationResponse"""
        TextPersonNameAnnotationResponse(
            text_person_name_annotations=[
                TextPersonNameAnnotation(start=10, length=10, text="foobar", confidence=95.5)
            ]
        )


if __name__ == '__main__':
    unittest.main()



"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.note import Note
from nlpsandbox.models import NoteId, PatientId
globals()['Note'] = Note
from nlpsandbox.model.text_physical_address_annotation_request import TextPhysicalAddressAnnotationRequest


class TestTextPhysicalAddressAnnotationRequest(unittest.TestCase):
    """TextPhysicalAddressAnnotationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTextPhysicalAddressAnnotationRequest(self):
        """Test TextPhysicalAddressAnnotationRequest"""
        TextPhysicalAddressAnnotationRequest(
            note=Note(
                identifier=NoteId("identifier"),
                text="text", type="type",
                patient_id=PatientId('patient-1')
            )
        )


if __name__ == '__main__':
    unittest.main()



"""
    NLP Sandbox Data Node API

    # Overview  The NLP Sandbox Data Node is a repository of data used to benchmark NLP Tools like the NLP Sandbox Date Annotator and Person Name Annotator.  The resources that can be stored in this Data Node and the operations supported are listed below:  - Create and manage datasets - Create and manage FHIR stores   - Store and retrieve FHIR patient profiles   - Store and retrieve clinical   notes - Create and manage annotation stores   - Store and retrieve text annotations   # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: team@nlpsandbox.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.text_covid_symptom_annotation_all_of import TextCovidSymptomAnnotationAllOf


class TestTextCovidSymptomAnnotationAllOf(unittest.TestCase):
    """TextCovidSymptomAnnotationAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTextCovidSymptomAnnotationAllOf(self):
        """Test TextCovidSymptomAnnotationAllOf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TextCovidSymptomAnnotationAllOf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python3
import click

from nlpsandboxclient import utils


# Command Group
@click.group(name='community', no_args_is_help=True)
def cli():
    """Commands for NLP Sandbox users."""


@cli.command()
def get_num_users():
    """Gets the number of NLP Sandbox users"""
    syn = utils.synapse_login()
    res = syn.restGET("/teamMembers/count/3413388")
    print(f"Number of NLP sandbox users: {res['count']}")


if __name__ == '__main__':
    cli()



"""
    NLP Sandbox API

    NLP Sandbox REST API  # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: team@nlpsandbox.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.masking_char_config import MaskingCharConfig


class TestMaskingCharConfig(unittest.TestCase):
    """MaskingCharConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMaskingCharConfig(self):
        """Test MaskingCharConfig"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MaskingCharConfig()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python3
import click

from nlpsandboxclient import evaluation, utils


@click.group(name='evaluate', no_args_is_help=True)
def cli():
    """Evaluation related commands"""


@cli.command(name="evaluate-prediction", no_args_is_help=True)
@click.option('--pred_filepath', help='Prediction filepath',
              type=click.Path(exists=True), required=True)
@click.option('--gold_filepath', help='Gold standard filepath',
              type=click.Path(exists=True), required=True)
@click.option('--output', help='Specify output json path',
              type=click.Path())
@click.option('--tool_type', help='The type of tool to evaluate.',
              type=click.Choice(['nlpsandbox:date-annotator',
                                 'nlpsandbox:person-name-annotator',
                                 'nlpsandbox:physical-address-annotator',
                                 'nlpsandbox:id-annotator',
                                 'nlpsandbox:contact-annotator'],
                                case_sensitive=False), required=True)
def evaluate_prediction(pred_filepath, gold_filepath, output, tool_type):
    """Evaluate the performance of a prediction file. Example prediction and
    goldstandard files are found in test/data/new_prediction.json and
    test/data/new_goldstandard.json respectively.
    """
    eval_mapping = {
        "nlpsandbox:date-annotator": evaluation.DateEvaluation,
        "nlpsandbox:person-name-annotator": evaluation.PersonNameEvaluation,
        "nlpsandbox:physical-address-annotator": evaluation.PhysicalAddressEvaluation,
        'nlpsandbox:id-annotator': evaluation.IdEvaluation,
        'nlpsandbox:contact-annotator': evaluation.ContactEvaluation
    }
    evaluator = eval_mapping[tool_type]()

    evaluator.convert_dict(pred_filepath, gold_filepath)
    results = evaluator.eval()
    utils.stdout_or_json(results, output)


if __name__ == '__main__':
    cli()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from nlpsandbox.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from nlpsandbox.model.annotation import Annotation
from nlpsandbox.model.annotation_create_request import AnnotationCreateRequest
from nlpsandbox.model.annotation_create_response import AnnotationCreateResponse
from nlpsandbox.model.annotation_id import AnnotationId
from nlpsandbox.model.annotation_name import AnnotationName
from nlpsandbox.model.annotation_set import AnnotationSet
from nlpsandbox.model.annotation_source import AnnotationSource
from nlpsandbox.model.annotation_store import AnnotationStore
from nlpsandbox.model.annotation_store_create_response import AnnotationStoreCreateResponse
from nlpsandbox.model.annotation_store_id import AnnotationStoreId
from nlpsandbox.model.annotation_store_name import AnnotationStoreName
from nlpsandbox.model.dataset import Dataset
from nlpsandbox.model.dataset_create_response import DatasetCreateResponse
from nlpsandbox.model.dataset_id import DatasetId
from nlpsandbox.model.dataset_name import DatasetName
from nlpsandbox.model.date_offset_config import DateOffsetConfig
from nlpsandbox.model.deidentification_step import DeidentificationStep
from nlpsandbox.model.deidentify_request import DeidentifyRequest
from nlpsandbox.model.deidentify_response import DeidentifyResponse
from nlpsandbox.model.error import Error
from nlpsandbox.model.fhir_store import FhirStore
from nlpsandbox.model.fhir_store_create_response import FhirStoreCreateResponse
from nlpsandbox.model.fhir_store_id import FhirStoreId
from nlpsandbox.model.fhir_store_name import FhirStoreName
from nlpsandbox.model.health_check import HealthCheck
from nlpsandbox.model.license import License
from nlpsandbox.model.masking_char_config import MaskingCharConfig
from nlpsandbox.model.note import Note
from nlpsandbox.model.note_create_request import NoteCreateRequest
from nlpsandbox.model.note_create_response import NoteCreateResponse
from nlpsandbox.model.note_id import NoteId
from nlpsandbox.model.note_resource_name import NoteResourceName
from nlpsandbox.model.page_limit import PageLimit
from nlpsandbox.model.page_of_annotation_stores import PageOfAnnotationStores
from nlpsandbox.model.page_of_annotation_stores_all_of import PageOfAnnotationStoresAllOf
from nlpsandbox.model.page_of_annotations import PageOfAnnotations
from nlpsandbox.model.page_of_annotations_all_of import PageOfAnnotationsAllOf
from nlpsandbox.model.page_of_datasets import PageOfDatasets
from nlpsandbox.model.page_of_datasets_all_of import PageOfDatasetsAllOf
from nlpsandbox.model.page_of_fhir_stores import PageOfFhirStores
from nlpsandbox.model.page_of_fhir_stores_all_of import PageOfFhirStoresAllOf
from nlpsandbox.model.page_of_notes import PageOfNotes
from nlpsandbox.model.page_of_notes_all_of import PageOfNotesAllOf
from nlpsandbox.model.page_of_patients import PageOfPatients
from nlpsandbox.model.page_of_patients_all_of import PageOfPatientsAllOf
from nlpsandbox.model.page_offset import PageOffset
from nlpsandbox.model.patient import Patient
from nlpsandbox.model.patient_create_request import PatientCreateRequest
from nlpsandbox.model.patient_create_response import PatientCreateResponse
from nlpsandbox.model.patient_id import PatientId
from nlpsandbox.model.patient_resource_name import PatientResourceName
from nlpsandbox.model.resource_source import ResourceSource
from nlpsandbox.model.response_page_metadata import ResponsePageMetadata
from nlpsandbox.model.response_page_metadata_links import ResponsePageMetadataLinks
from nlpsandbox.model.text_annotation import TextAnnotation
from nlpsandbox.model.text_contact_annotation import TextContactAnnotation
from nlpsandbox.model.text_contact_annotation_all_of import TextContactAnnotationAllOf
from nlpsandbox.model.text_contact_annotation_request import TextContactAnnotationRequest
from nlpsandbox.model.text_contact_annotation_response import TextContactAnnotationResponse
from nlpsandbox.model.text_covid_symptom_annotation import TextCovidSymptomAnnotation
from nlpsandbox.model.text_covid_symptom_annotation_all_of import TextCovidSymptomAnnotationAllOf
from nlpsandbox.model.text_covid_symptom_annotation_request import TextCovidSymptomAnnotationRequest
from nlpsandbox.model.text_covid_symptom_annotation_response import TextCovidSymptomAnnotationResponse
from nlpsandbox.model.text_date_annotation import TextDateAnnotation
from nlpsandbox.model.text_date_annotation_all_of import TextDateAnnotationAllOf
from nlpsandbox.model.text_date_annotation_request import TextDateAnnotationRequest
from nlpsandbox.model.text_date_annotation_response import TextDateAnnotationResponse
from nlpsandbox.model.text_id_annotation import TextIdAnnotation
from nlpsandbox.model.text_id_annotation_all_of import TextIdAnnotationAllOf
from nlpsandbox.model.text_id_annotation_request import TextIdAnnotationRequest
from nlpsandbox.model.text_id_annotation_response import TextIdAnnotationResponse
from nlpsandbox.model.text_person_name_annotation import TextPersonNameAnnotation
from nlpsandbox.model.text_person_name_annotation_request import TextPersonNameAnnotationRequest
from nlpsandbox.model.text_person_name_annotation_response import TextPersonNameAnnotationResponse
from nlpsandbox.model.text_physical_address_annotation import TextPhysicalAddressAnnotation
from nlpsandbox.model.text_physical_address_annotation_all_of import TextPhysicalAddressAnnotationAllOf
from nlpsandbox.model.text_physical_address_annotation_request import TextPhysicalAddressAnnotationRequest
from nlpsandbox.model.text_physical_address_annotation_response import TextPhysicalAddressAnnotationResponse
from nlpsandbox.model.tool import Tool
from nlpsandbox.model.tool_dependencies import ToolDependencies
from nlpsandbox.model.tool_type import ToolType



"""Test client functions"""
from unittest.mock import Mock, patch

import pytest

import nlpsandbox
from nlpsandbox.api import (
    annotation_api, annotation_store_api,
    dataset_api, note_api,
    text_contact_annotation_api,
    text_covid_symptom_annotation_api,
    text_date_annotation_api,
    text_id_annotation_api,
    text_person_name_annotation_api,
    text_physical_address_annotation_api,
    tool_api,
)
from nlpsandbox.models import (
    Annotation, AnnotationName, AnnotationSource,
    AnnotationStore, AnnotationStoreName, Dataset, DatasetName,
    License, PageLimit, PageOfAnnotations, PageOfDatasets,
    PageOfNotes, PageOffset, PatientId, Note, NoteId,
    TextDateAnnotation, TextDateAnnotationResponse, Tool,
    ToolType, ResourceSource, ResponsePageMetadataLinks,
)
from nlpsandbox.rest import ApiException
from nlpsandboxclient import client


# def test_get_notes():
#     configuration = Mock()
#     api = Mock()
#     note_api_mock = Mock()
#     host = "0.0.0.0"
#     configuration = Mock()
#     note_example = PageOfNotes(
#         notes=[Note(
#             id="12344", type="foo", patient_id="pat1", text="foobarbaz"
#         )],
#         offset=0, limit=3, links=Mock(next="")
#     )

#     with patch.object(nlpsandbox, "Configuration",
#                       return_value=configuration) as config,\
#          patch.object(nlpsandbox, "ApiClient") as api_client,\
#          patch.object(nlpsandbox, "NoteApi",
#                       return_value=note_api_mock) as note_api,\
#          patch.object(note_api_mock, "list_notes",
#                       return_value=note_example) as list_notes:

#         # To mock context manager
#         api_client.return_value = api_client
#         api_client.__enter__ = Mock(return_value=api)
#         api_client.__exit__ = Mock(return_value=None)

#         notes = client.get_notes(
#             host=host,
#             dataset_id="awesome-dataset",
#             fhir_store_id="awesome-fhir-store"
#         )
#         config.assert_called_once_with(host=host)
#         api_client.assert_called_once_with(configuration)
#         note_api.assert_called_once_with(api)
#         list_notes.assert_called_once_with("awesome-dataset",
#                                            "awesome-fhir-store",
#                                            limit=10, offset=0)
#         assert notes == [{
#             'id': '12344',
#             'noteType': 'foo',
#             'patientId': 'pat1',
#             'text': 'foobarbaz',
#             'note_name': 'dataset/awesome-dataset/fhirStores/awesome-fhir-store/fhir/Note/12344'
#         }]


class TestDataNodeClient:

    def setup_method(self):
        self.configuration = nlpsandbox.Configuration()
        self.api = nlpsandbox.ApiClient()
        self.mock_api = Mock()
        self.host = "0.0.0.0"
        self.config = patch.object(nlpsandbox, "Configuration",
                                   return_value=self.configuration)
        self.api_client = patch.object(nlpsandbox, "ApiClient")
        self.dataset_id = "awesome-dataset"
        self.annotation_store_id = "annotation-store"
        self.annotation_id = "awesome-annotation"
        self.fhir_store_id = "fhir-store"
        # To mock context manager

    def test_list_notes(self):
        note_example = PageOfNotes(
            notes=[
                Note(identifier=NoteId("12344"), type="foo", patient_id=PatientId("pat1"), text="foobarbaz")
            ],
            offset=PageOffset(10),
            limit=PageLimit(10),
            links=ResponsePageMetadataLinks(next=""),
            total_results=30,
        )
        with self.config as config,\
             self.api_client as api_client,\
             patch.object(note_api, "NoteApi",
                          return_value=self.mock_api) as patch_note_api,\
             patch.object(self.mock_api, "list_notes",
                          return_value=note_example) as list_notes:

            # To mock context manager
            api_client.return_value = api_client
            api_client.__enter__ = Mock(return_value=self.api)
            api_client.__exit__ = Mock(return_value=None)

            notes = list(client.list_notes(
                host=self.host,
                dataset_id=self.dataset_id,
                fhir_store_id=self.fhir_store_id
            ))
            config.assert_called_once_with(host=self.host)
            api_client.assert_called_once_with(self.configuration)
            patch_note_api.assert_called_once_with(self.api)
            list_notes.assert_called_once_with(self.dataset_id,
                                               self.fhir_store_id,
                                               limit=10, offset=0)
            assert notes == [{
                'identifier': '12344',
                'type': 'foo',
                'patientId': 'pat1',
                'text': 'foobarbaz',
                'note_name': f'dataset/{self.dataset_id}/fhirStores/{self.fhir_store_id}/fhir/Note/12344'
            }]

    def test_get_annotation_store__get(self):
        """Test getting of annotation store"""
        store_example = AnnotationStore(name=AnnotationStoreName("fooo"))

        with self.config as config,\
            self.api_client as api_client,\
            patch.object(annotation_store_api, "AnnotationStoreApi",
                         return_value=self.mock_api) as resource_api,\
            patch.object(self.mock_api, "get_annotation_store",
                         return_value=store_example) as get_store:

            api_client.return_value = api_client
            api_client.__enter__ = Mock(return_value=self.api)
            api_client.__exit__ = Mock(return_value=None)

            store = client.get_annotation_store(
                host=self.host,
                dataset_id =self.dataset_id,
                annotation_store_id = self.fhir_store_id
            )
            config.assert_called_once_with(host=self.host)
            api_client.assert_called_once_with(self.configuration)
            resource_api.assert_called_once_with(self.api)
            get_store.assert_called_once_with(self.dataset_id,
                                              self.fhir_store_id)
            assert store == store_example

    def test_get_annotation_store__not_create(self):
        """Test creating of annotation store if create_if_missing is False"""
        with self.config as config,\
             self.api_client as api_client,\
             patch.object(annotation_store_api, "AnnotationStoreApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api, "get_annotation_store",
                          side_effect=ApiException(status=404)) as get_store,\
             pytest.raises(ApiException):

            api_client.return_value = api_client
            api_client.__enter__ = Mock(return_value=self.api)
            api_client.__exit__ = Mock(return_value=None)

            client.get_annotation_store(
                host=self.host,
                dataset_id = self.dataset_id,
                annotation_store_id = self.annotation_store_id,
            )
            config.assert_called_once_with(host=self.host)
            api_client.assert_called_once_with(self.configuration)
            resource_api.assert_called_once_with(self.api)

    def test_get_annotation_store__create(self):
        """Test creating of annotation store if create_if_missing is True"""
        store_example = AnnotationStore(name=AnnotationStoreName("fooo"))

        with self.config as config,\
             self.api_client as api_client,\
             patch.object(annotation_store_api, "AnnotationStoreApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api, "get_annotation_store",
                          side_effect=ApiException(status=404)) as get_store,\
             patch.object(self.mock_api, "create_annotation_store",
                          return_value=store_example) as create_store:

            api_client.return_value = api_client
            api_client.__enter__ = Mock(return_value=self.api)
            api_client.__exit__ = Mock(return_value=None)

            store = client.get_annotation_store(
                host=self.host, dataset_id = self.dataset_id,
                annotation_store_id = self.fhir_store_id,
                create_if_missing = True
            )

            config.assert_called_once_with(host=self.host)
            api_client.assert_called_once_with(self.configuration)
            resource_api.assert_called_once_with(self.api)
            get_store.assert_called_once_with(self.dataset_id,
                                              self.fhir_store_id)
            assert store == store_example

    def test_list_annotations(self):
        """Test listing of annotations"""
        annotation_example = PageOfAnnotations(
            annotations=[
                Annotation(
                    name=AnnotationName("12344"),
                    annotation_source=AnnotationSource(resource_source=ResourceSource(name="foo")),
                )
            ],
            offset=PageOffset(10),
            limit=PageLimit(10),
            links=ResponsePageMetadataLinks(next=""),
            total_results=30
        )

        with self.config as config,\
             self.api_client as api_client,\
             patch.object(annotation_api, "AnnotationApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api, "list_annotations",
                          return_value=annotation_example) as list_annotations:

            api_client.return_value = api_client
            api_client.__enter__ = Mock(return_value=self.api)
            api_client.__exit__ = Mock(return_value=None)

            annotations = client.list_annotations(
                host=self.host, dataset_id = self.dataset_id,
                annotation_store_id = self.annotation_store_id
            )
            assert list(annotations) == [
                {'name': '12344', 'annotationSource': {'resourceSource': {'name': 'foo'}}}
            ]

            config.assert_called_once_with(host=self.host)
            api_client.assert_called_once_with(self.configuration)
            resource_api.assert_called_once_with(self.api)
            list_annotations.assert_called_once_with(
                self.dataset_id, self.annotation_store_id,
                offset=0, limit=10
            )

    def test_list_datasets(self):
        """Test listing of datasets"""
        example_datasets = PageOfDatasets(
            datasets=[
                Dataset(name=DatasetName("foo"))
            ],
            offset=PageOffset(10),
            limit=PageLimit(10),
            links=ResponsePageMetadataLinks(next=""),
            total_results=30
        )

        with self.config as config,\
             self.api_client as api_client,\
             patch.object(dataset_api, "DatasetApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api, "list_datasets",
                          return_value=example_datasets) as list_datasets:

            api_client.return_value = api_client
            api_client.__enter__ = Mock(return_value=self.api)
            api_client.__exit__ = Mock(return_value=None)

            datasets = client.list_datasets(host=self.host)
            assert list(datasets) == [
                {'name': 'foo'}
            ]
            config.assert_called_once_with(host=self.host)
            api_client.assert_called_once_with(self.configuration)
            resource_api.assert_called_once_with(self.api)
            list_datasets.assert_called_once_with(limit=10, offset=0)

    def test_get_annotation(self):
        """Test getting of annotation"""
        example_annotation = Annotation(
            name=AnnotationName("12344"),
            annotation_source=AnnotationSource(resource_source=ResourceSource(name="foo")),
        )
        with self.config as config,\
             self.api_client as api_client,\
             patch.object(annotation_api, "AnnotationApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api, "get_annotation",
                          return_value=example_annotation) as get_annotation:

            api_client.return_value = api_client
            api_client.__enter__ = Mock(return_value=self.api)
            api_client.__exit__ = Mock(return_value=None)

            annotation = client.get_annotation(
                host=self.host, dataset_id=self.dataset_id,
                annotation_store_id=self.annotation_store_id,
                annotation_id=self.annotation_id
            )
            assert annotation == example_annotation
            config.assert_called_once_with(host=self.host)
            api_client.assert_called_once_with(self.configuration)
            resource_api.assert_called_once_with(self.api)
            get_annotation.assert_called_once_with(
                self.dataset_id, self.annotation_store_id,
                self.annotation_id
            )

    def test__store_annotations(self):
        return_obj = Mock()
        example_annotation = Annotation(
            name=AnnotationName("12344"),
            annotation_source=AnnotationSource(resource_source=ResourceSource(name="foo")),
        )
        with self.config as config,\
             self.api_client as api_client,\
             patch.object(annotation_api, "AnnotationApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api, "create_annotation",
                          return_value=return_obj) as patch_store:

            api_client.return_value = api_client
            api_client.__enter__ = Mock(return_value=self.api)
            api_client.__exit__ = Mock(return_value=None)

            annotation = client._store_annotation(
                host=self.host, dataset_id=self.dataset_id,
                annotation_store_id=self.annotation_store_id,
                annotation_id=self.annotation_id,
                annotation=example_annotation
            )
            config.assert_called_once_with(host=self.host)
            api_client.assert_called_once_with(self.configuration)
            resource_api.assert_called_once_with(self.api)
            patch_store.assert_called_once_with(
                annotation_create_request=example_annotation,
                annotation_id='awesome-annotation',
                annotation_store_id='annotation-store',
                async_req=True, dataset_id='awesome-dataset'
            )


class TestAnnotatorClient:

    def setup_method(self):
        self.configuration = nlpsandbox.Configuration()
        self.api = nlpsandbox.ApiClient()
        self.mock_api = Mock()
        self.host = "0.0.0.0"
        self.config = patch.object(nlpsandbox, "Configuration",
                                   return_value=self.configuration)
        self.api_client = patch.object(nlpsandbox, "ApiClient")
        self.example_note = {
            "identifier": "note-1",
            "type": "loinc:LP29684-5",
            "patientId": "507f1f77bcf86cd799439011",
            "text": "On 12/26/2020, Ms. Chloe Price met with Dr. Prescott."
        }
        self.example_request = {
            "note": {
                "identifier": "note-1",
                "type": "loinc:LP29684-5",
                "patient_id": "507f1f77bcf86cd799439011",
                "text": "On 12/26/2020, Ms. Chloe Price met with Dr. Prescott."
            }
        }
        self.date_response = TextDateAnnotationResponse(
            text_date_annotations=[
                TextDateAnnotation(start=10, length=10, text="foobar", confidence=95.5)
            ]
        )

    def test__annotate_date(self):
        """Test annotating date"""
        with patch.object(text_date_annotation_api, "TextDateAnnotationApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api, "create_text_date_annotations",
                          return_value="foo") as create_annotations:
            annotated = client._annotate_date(self.api, self.example_request)
            assert annotated == "foo"
            resource_api.assert_called_once_with(self.api)
            create_annotations.assert_called_once_with(
                text_date_annotation_request=self.example_request
            )

    def test__annotate_person_name(self):
        """Test annotating person"""
        with patch.object(text_person_name_annotation_api, "TextPersonNameAnnotationApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api, "create_text_person_name_annotations",
                          return_value="foo") as create_annotations:
            annotated = client._annotate_person_name(self.api, self.example_request)
            assert annotated == "foo"
            resource_api.assert_called_once_with(self.api)
            create_annotations.assert_called_once_with(
                text_person_name_annotation_request=self.example_request
            )

    def test__annotate_physical_address(self):
        """Test annotating physical address"""
        with patch.object(text_physical_address_annotation_api, "TextPhysicalAddressAnnotationApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api, "create_text_physical_address_annotations",
                          return_value="foo") as create_annotations:
            annotated = client._annotate_physical_address(self.api, self.example_request)
            assert annotated == "foo"
            resource_api.assert_called_once_with(self.api)
            create_annotations.assert_called_once_with(
                text_physical_address_annotation_request=self.example_request
            )

    def test__annotate_id(self):
        """Test annotating id"""
        with patch.object(text_id_annotation_api, "TextIdAnnotationApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api, "create_text_id_annotations",
                          return_value="foo") as create_annotations:
            annotated = client._annotate_id(self.api, self.example_request)
            assert annotated == "foo"
            resource_api.assert_called_once_with(self.api)
            create_annotations.assert_called_once_with(
                text_id_annotation_request=self.example_request
            )

    def test__annotate_contact(self):
        """Test annotating id"""
        with patch.object(text_contact_annotation_api, "TextContactAnnotationApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api, "create_text_contact_annotations",
                          return_value="foo") as create_annotations:
            annotated = client._annotate_contact(self.api, self.example_request)
            assert annotated == "foo"
            resource_api.assert_called_once_with(self.api)
            create_annotations.assert_called_once_with(
                text_contact_annotation_request=self.example_request
            )

    def test__annotate_covid_symptom(self):
        """Test annotating id"""
        with patch.object(text_covid_symptom_annotation_api,
                          "TextCovidSymptomAnnotationApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api,
                          "create_text_covid_symptom_annotations",
                          return_value="foo") as create_annotations:
            annotated = client._annotate_covid_symptom(self.api,
                                                       self.example_request)
            assert annotated == "foo"
            resource_api.assert_called_once_with(self.api)
            create_annotations.assert_called_once_with(
                text_covid_symptom_annotation_request=self.example_request
            )

    def test_annotate_note__wrong_tool_type(self):
        """Wrong tool type"""
        with pytest.raises(ValueError, match="Invalid annotator_type: foo"):
            client.annotate_note(host=self.host, note=self.example_note,
                                 tool_type="foo")

    @pytest.mark.parametrize("tool_type,tool_func", [
        ("nlpsandbox:date-annotator", "_annotate_date"),
        ("nlpsandbox:person-name-annotator", "_annotate_person_name"),
        ("nlpsandbox:physical-address-annotator",
         "_annotate_physical_address"),
        ("nlpsandbox:id-annotator", "_annotate_id"),
        ("nlpsandbox:covid-symptom-annotator", "_annotate_covid_symptom"),
        ("nlpsandbox:contact-annotator", "_annotate_contact"),
    ])
    def test_annotate_note(self, tool_type, tool_func):
        """Test annotate note"""
        with self.config as config,\
             self.api_client as api_client,\
             patch.object(client, tool_func,
                          return_value=self.date_response) as patch_annot:
            api_client.return_value = api_client
            api_client.__enter__ = Mock(return_value=self.api)
            api_client.__exit__ = Mock(return_value=None)

            result = client.annotate_note(
                host=self.host, note=self.example_note, tool_type=tool_type
            )
            config.assert_called_once_with(host=self.host)
            api_client.assert_called_once_with(self.configuration)
            patch_annot.assert_called_once_with(self.api, self.example_request)
            assert result == {
                'textDateAnnotations': [
                    {'start': 10, 'length': 10, 'text': 'foobar', 'confidence': 95.5}
                ]
            }

    def test_get_tool(self):
        """Get tool"""
        tool_example = Tool(
            name="foo", version="1.0.0", license=License("apache-2.0"),
            repository="www.google.com", description="foobar",
            author="Bob", author_email="email@email.com", url="www.google.com",
            type=ToolType("tool"), api_version="1.0.0"
        )
        with self.config as config,\
             self.api_client as api_client,\
             patch.object(tool_api, "ToolApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api, "get_tool",
                          return_value=tool_example) as get_tool,\
             patch.object(client, "_get_tool_redirect",
                          return_value=tool_example.to_dict()):
            api_client.return_value = api_client
            api_client.__enter__ = Mock(return_value=self.api)
            api_client.__exit__ = Mock(return_value=None)
            tool = client.get_tool(host=self.host)
            assert tool == tool_example

    def test_get_tool__invalid(self):
        """Tool and redirect don't match"""
        tool_example = Tool(
            name="foo", version="1.0.0", license=License("apache-2.0"),
            repository="www.google.com", description="foobar",
            author="Bob", author_email="email@email.com", url="www.google.com",
            type=ToolType("tool"), api_version="1.0.0"
        )
        with self.config as config,\
             self.api_client as api_client,\
             patch.object(tool_api, "ToolApi",
                          return_value=self.mock_api) as resource_api,\
             patch.object(self.mock_api, "get_tool",
                          return_value=tool_example) as get_tool,\
             patch.object(client, "_get_tool_redirect",
                          return_value={}),\
             pytest.raises(ValueError, match="Tool base URL must redirect*"):
            api_client.return_value = api_client
            api_client.__enter__ = Mock(return_value=self.api)
            api_client.__exit__ = Mock(return_value=None)
            tool = client.get_tool(host=self.host)



"""
    NLP Sandbox API

    NLP Sandbox REST API  # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: team@nlpsandbox.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import nlpsandbox
from nlpsandbox.api.deidentified_note_api import DeidentifiedNoteApi  # noqa: E501


class TestDeidentifiedNoteApi(unittest.TestCase):
    """DeidentifiedNoteApi unit test stubs"""

    def setUp(self):
        self.api = DeidentifiedNoteApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_deidentified_notes(self):
        """Test case for create_deidentified_notes

        Deidentify a clinical note  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    NLP Sandbox Data Node API

    # Overview  The NLP Sandbox Data Node is a repository of data used to benchmark NLP Tools like the NLP Sandbox Date Annotator and Person Name Annotator.  The resources that can be stored in this Data Node and the operations supported are listed below:  - Create and manage datasets - Create and manage FHIR stores   - Store and retrieve FHIR patient profiles   - Store and retrieve clinical   notes - Create and manage annotation stores   - Store and retrieve text annotations   # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: team@nlpsandbox.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.annotation_name import AnnotationName
from nlpsandbox.model.annotation_source import AnnotationSource
from nlpsandbox.model.text_contact_annotation import TextContactAnnotation
from nlpsandbox.model.text_covid_symptom_annotation import TextCovidSymptomAnnotation
from nlpsandbox.model.text_date_annotation import TextDateAnnotation
from nlpsandbox.model.text_id_annotation import TextIdAnnotation
from nlpsandbox.model.text_person_name_annotation import TextPersonNameAnnotation
from nlpsandbox.model.text_physical_address_annotation import TextPhysicalAddressAnnotation
globals()['AnnotationName'] = AnnotationName
globals()['AnnotationSource'] = AnnotationSource
globals()['TextContactAnnotation'] = TextContactAnnotation
globals()['TextCovidSymptomAnnotation'] = TextCovidSymptomAnnotation
globals()['TextDateAnnotation'] = TextDateAnnotation
globals()['TextIdAnnotation'] = TextIdAnnotation
globals()['TextPersonNameAnnotation'] = TextPersonNameAnnotation
globals()['TextPhysicalAddressAnnotation'] = TextPhysicalAddressAnnotation
from nlpsandbox.model.annotation import Annotation


class TestAnnotation(unittest.TestCase):
    """Annotation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAnnotation(self):
        """Test Annotation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Annotation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    NLP Sandbox Data Node API

    # Overview  The NLP Sandbox Data Node is a repository of data used to benchmark NLP Tools like the NLP Sandbox Date Annotator and Person Name Annotator.  The resources that can be stored in this Data Node and the operations supported are listed below:  - Create and manage datasets - Create and manage FHIR stores   - Store and retrieve FHIR patient profiles   - Store and retrieve clinical   notes - Create and manage annotation stores   - Store and retrieve text annotations   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import unittest
from unittest.mock import patch

import nlpsandbox
from nlpsandbox.api.annotation_api import AnnotationApi  # noqa: E501
from nlpsandbox.models import ResourceSource


class TestAnnotationApi(unittest.TestCase):
    """AnnotationApi unit test stubs"""

    def setUp(self):
        self.api = AnnotationApi()  # noqa: E501
        self.patcher = patch('nlpsandbox.api_client.ApiClient.call_api')
        self.mock_foo = self.patcher.start()

    def tearDown(self):
        self.patcher.stop()

    def test_create_annotation(self):
        """Test case for create_annotation

        Create an annotation  # noqa: E501
        """
        self.api.create_annotation(
            dataset_id="awesome-dataset",
            annotation_store_id="awesome-annotation-store",
            annotation_id="awesome-annotation",
            annotation_create_request={
                "annotation_source": {
                    "resource_source": ResourceSource("source")
                },
                "text_date_annotations": []
            }
        )

    def test_delete_annotation(self):
        """Test case for delete_annotation

        Delete an annotation  # noqa: E501
        """
        self.api.delete_annotation(
            dataset_id="data",
            annotation_store_id="data",
            annotation_id="data"
        )

    def test_get_annotation(self):
        """Test case for get_annotation

        Get an annotation  # noqa: E501
        """
        self.api.get_annotation(
            dataset_id="data",
            annotation_store_id="data",
            annotation_id="data"
        )

    def test_list_annotations(self):
        """Test case for list_annotations

        List the annotations in an annotation store  # noqa: E501
        """
        self.api.list_annotations(
            dataset_id="data",
            annotation_store_id="data"
        )


if __name__ == '__main__':
    unittest.main()



"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.text_date_annotation import TextDateAnnotation
globals()['TextDateAnnotation'] = TextDateAnnotation
from nlpsandbox.model.text_date_annotation_response import TextDateAnnotationResponse


class TestTextDateAnnotationResponse(unittest.TestCase):
    """TextDateAnnotationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTextDateAnnotationResponse(self):
        """Test TextDateAnnotationResponse"""
        TextDateAnnotationResponse(
            text_date_annotations=[
                TextDateAnnotation(start=10, length=10, text="foobar", confidence=95.5)
            ]
        )


if __name__ == '__main__':
    unittest.main()



"""
    NLP Sandbox Data Node API

    # Overview  The NLP Sandbox Data Node is a repository of data used to benchmark NLP Tools like the NLP Sandbox Date Annotator and Person Name Annotator.  The resources that can be stored in this Data Node and the operations supported are listed below:  - Create and manage datasets - Create and manage FHIR stores   - Store and retrieve FHIR patient profiles   - Store and retrieve clinical   notes - Create and manage annotation stores   - Store and retrieve text annotations   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import unittest
from unittest.mock import patch

import nlpsandbox
from nlpsandbox.api.patient_api import PatientApi  # noqa: E501


class TestPatientApi(unittest.TestCase):
    """PatientApi unit test stubs"""

    def setUp(self):
        self.api = PatientApi()  # noqa: E501
        self.patcher = patch('nlpsandbox.api_client.ApiClient.call_api')
        self.mock_foo = self.patcher.start()

    def tearDown(self):
        self.patcher.stop()

    def test_create_patient(self):
        """Test case for create_patient

        Create a FHIR patient  # noqa: E501
        """
        self.api.create_patient(
            dataset_id="awesome-dataset-id",
            fhir_store_id="awesome-fhir-store",
            patient_id="awesome-patient",
            patient_create_request={"gender": "female"}
        )

    def test_delete_patient(self):
        """Test case for delete_patient

        Delete a FHIR patient  # noqa: E501
        """
        self.api.delete_patient(
            dataset_id="awesome-dataset-id",
            fhir_store_id="awesome-fhir-store",
            patient_id="awesome-patient"
        )

    def test_get_patient(self):
        """Test case for get_patient

        Get a FHIR patient  # noqa: E501
        """
        self.api.get_patient(
            dataset_id="awesome-dataset-id",
            fhir_store_id="awesome-fhir-store",
            patient_id="awesome-patient"
        )

    def test_list_patients(self):
        """Test case for list_patients

        List the Patients in a FHIR store  # noqa: E501
        """
        self.api.list_patients(
            dataset_id="awesome-dataset-id",
            fhir_store_id="awesome-fhir-store"
        )


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

"""
    NLP Sandbox API

    NLP Sandbox REST API  # noqa: E501

    The version of the OpenAPI document: 1.1.2
    Contact: team@nlpsandbox.io
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from nlpsandbox.api_client import ApiClient

# import Configuration
from nlpsandbox.configuration import Configuration

# import exceptions
from nlpsandbox.exceptions import OpenApiException
from nlpsandbox.exceptions import ApiAttributeError
from nlpsandbox.exceptions import ApiTypeError
from nlpsandbox.exceptions import ApiValueError
from nlpsandbox.exceptions import ApiKeyError
from nlpsandbox.exceptions import ApiException



import os
import setuptools


def read(rel_path: str) -> str:
    """Read file"""
    # type: (str) -> str
    here = os.path.abspath(os.path.dirname(__file__))
    # intentionally *not* adding an encoding option to open, See:
    #   https://github.com/pypa/virtualenv/issues/201#issuecomment-3145690
    with open(os.path.join(here, rel_path)) as fp:
        return fp.read()


def get_version(rel_path: str) -> str:
    """Get version from __init__.py: following pip setup.py example
    https://github.com/pypa/pip/blob/master/setup.py#L11
    """
    for line in read(rel_path).splitlines():
        if line.startswith('__version__'):
            # __version__ = "0.9"
            delim = '"' if '"' in line else "'"
            return line.split(delim)[1]
    raise RuntimeError("Unable to find version string.")


with open("README.md", "r") as fh:
    long_description = fh.read()


setuptools.setup(
    # basic
    name='nlpsandbox-client',
    version=get_version("nlpsandboxclient/__init__.py"),
    # packages=setuptools.find_packages(exclude=["tests", "tests.*"]),
    # py_modules=['hello'],
    # scripts=['bin/nlp-evaluate'],

    packages=setuptools.find_packages(),
    entry_points={
        'console_scripts': ['nlp-cli=nlpsandboxclient.cli.__main__:main']
    },

    # requirements
    python_requires='>=3.6.*',
    install_requires=[
        'certifi >= 14.05.14',
        'click >= 7.1.2',
        'jsonschema >= 3.2.0',
        'python_dateutil >= 2.5.3',
        'setuptools >= 21.0.0',
        'six >= 1.10',
        'synapseclient >= 2.2.0',
        'urllib3 >= 1.15.1',
        'nulltype >= 2.3.1'
    ],

    # metadata to display on PyPI
    description='NLP Sandbox Client Library for Python',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://nlpsandbox.io',
    author='The NLP Sandbox Team',
    author_email='team@nlpsandox.io',
    license='Apache',
    project_urls={
        "Source Code": "https://github.com/nlpsandbox/nlpsandbox-client",
        "Bug Tracker": "https://github.com/nlpsandbox/nlpsandbox-client/issues",
    },
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: Apache Software License',
        'Topic :: Software Development :: Libraries',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Bio-Informatics'
    ]
)



"""
    NLP Sandbox API

    NLP Sandbox REST API  # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: team@nlpsandbox.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.text_contact_annotation import TextContactAnnotation
from nlpsandbox.model.text_date_annotation import TextDateAnnotation
from nlpsandbox.model.text_id_annotation import TextIdAnnotation
from nlpsandbox.model.text_person_name_annotation import TextPersonNameAnnotation
from nlpsandbox.model.text_physical_address_annotation import TextPhysicalAddressAnnotation
globals()['TextContactAnnotation'] = TextContactAnnotation
globals()['TextDateAnnotation'] = TextDateAnnotation
globals()['TextIdAnnotation'] = TextIdAnnotation
globals()['TextPersonNameAnnotation'] = TextPersonNameAnnotation
globals()['TextPhysicalAddressAnnotation'] = TextPhysicalAddressAnnotation
from nlpsandbox.model.annotation_set import AnnotationSet


class TestAnnotationSet(unittest.TestCase):
    """AnnotationSet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAnnotationSet(self):
        """Test AnnotationSet"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AnnotationSet()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""Data node CLI"""
import json

import click

from nlpsandboxclient import client, utils
from nlpsandboxclient.client import DATA_NODE_HOST


# Command Group
@click.group(name='datanode', no_args_is_help=True)
def cli():
    """Commands to interact with NLP Data Node."""


@cli.command(no_args_is_help=True)
@click.option('--output', help='Output json filepath', type=click.Path())
@click.option('--data_node_host', help='Data node host',
              default=DATA_NODE_HOST, show_default=True)
@click.option('--dataset_id', help='Dataset id', required=True)
@click.option('--fhir_store_id', help='Dataset id', required=True)
def list_notes(output, data_node_host, dataset_id, fhir_store_id):
    """Gets clinical notes of a NLP data node FHIR store."""
    clinical_notes = client.list_notes(host=data_node_host,
                                       dataset_id=dataset_id,
                                       fhir_store_id=fhir_store_id)
    # Stdout or store to json
    utils.stdout_or_json(list(clinical_notes), output)


@cli.command(no_args_is_help=True)
@click.option('--data_node_host', help='Data node host',
              default=DATA_NODE_HOST, show_default=True)
@click.option('--dataset_id', help='Dataset id')
@click.option('--annotation_store_id', help='Annotation store id',
              required=True)
@click.option('--annotation_json', help='Json file with annotations to store',
              type=click.Path(exists=True), required=True)
def store_annotations(data_node_host, dataset_id, annotation_store_id,
                      annotation_json):
    """Store annotations in an NLP data node annotation store.
    The annotation store is deleted if it already exists.
    Sets the annotation_id as the note id.
    """
    with open(annotation_json, "r") as annot_f:
        annotations = json.load(annot_f)
    # If only one annotation is passed in, turn it into a list
    if isinstance(annotations, dict):
        annotations = [annotations]
    client.store_annotations(
        host=data_node_host,
        dataset_id=dataset_id,
        annotation_store_id=annotation_store_id,
        annotations=annotations
    )


@cli.command(no_args_is_help=True)
@click.option('--data_node_host', help='Data node host',
              default=DATA_NODE_HOST, show_default=True)
@click.option('--dataset_id', help='Dataset id', required=True)
@click.option('--annotation_store_id', help='Dataset id', required=True)
@click.option('--create_if_missing', help='Create resource if missing', is_flag=True)
def get_annotation_store(data_node_host, dataset_id, annotation_store_id, create_if_missing):
    """Create annotation store for a NLP data node dataset."""
    # Create annotation store object
    annotation_store = client.get_annotation_store(
        host=data_node_host, dataset_id=dataset_id,
        annotation_store_id=annotation_store_id,
        create_if_missing=create_if_missing
    )
    print(annotation_store.name)


@cli.command(no_args_is_help=True)
@click.option('--data_node_host', help='Data node host',
              default=DATA_NODE_HOST, show_default=True)
@click.option('--dataset_id', help='Dataset Id', required=True)
@click.option('--annotation_store_id', help='Dataset Id', required=True)
@click.option('--annotation_id', help='Annotation Id', required=True)
@click.option('--output', help='Output json filepath', type=click.Path())
def get_annotation(data_node_host, dataset_id, annotation_store_id,
                   annotation_id, output):
    """Get annotation for a NLP data node dataset."""
    annotation = client.get_annotation(
        host=data_node_host, dataset_id=dataset_id,
        annotation_store_id=annotation_store_id,
        annotation_id=annotation_id
    )
    utils.stdout_or_json(annotation.to_dict(), output)


@cli.command(no_args_is_help=True)
@click.option('--data_node_host', help='Data node host',
              default=DATA_NODE_HOST, show_default=True)
@click.option('--dataset_id', help='Dataset id', required=True)
@click.option('--annotation_store_id', help='Dataset id', required=True)
@click.option('--output', help='Output json filepath', type=click.Path())
def list_annotations(data_node_host, dataset_id, annotation_store_id, output):
    """List annotations of a NLP data node annotation store."""
    # Create annotation store object
    annotations = client.list_annotations(
        host=data_node_host, dataset_id=dataset_id,
        annotation_store_id=annotation_store_id
    )
    utils.stdout_or_json(list(annotations), output)


@cli.command()
@click.option('--data_node_host', help='Data node host',
              default=DATA_NODE_HOST, show_default=True)
@click.option('--output', help='Output json filepath', type=click.Path())
def list_datasets(data_node_host, output):
    """List annotations of a NLP data node annotation store."""
    # Create annotation store object
    datasets = client.list_datasets(
        host=data_node_host
    )
    utils.stdout_or_json(list(datasets), output)


@cli.command(no_args_is_help=True)
@click.option('--data_node_host', help='Data node host',
              default=DATA_NODE_HOST, show_default=True)
@click.option('--dataset_id', help='Dataset id', required=True)
@click.option('--output', help='Output json filepath', type=click.Path())
def store_dataset(data_node_host, dataset_id, output):
    """Create a dataset in the data node"""
    # Create dataset
    dataset = client.store_dataset(host=data_node_host,
                                   dataset_id=dataset_id)
    utils.stdout_or_json(dataset.to_dict(), output)


@cli.command(no_args_is_help=True)
@click.option('--data_node_host', help='Data node host',
              default=DATA_NODE_HOST, show_default=True)
@click.option('--dataset_id', help='Dataset id', required=True)
def delete_dataset(data_node_host, dataset_id):
    """Delete a dataset in the data node"""
    # Create dataset
    client.delete_dataset(host=data_node_host,
                          dataset_id=dataset_id)

# @cli.command()
# @click.argument('noteid', type=click.INT)
# @click.option('--output', help='Output json filepath', type=click.Path())
# @click.option('--data_node_host',
#               help='Data node host.  If not specified, uses '
#                    'http://0.0.0.0:8080/api/v1')
# def get_clinical_note(noteid, output, data_node_host):
#     """Gets clinical note of NOTEID"""
#     data_node_host = (data_node_host if data_node_host is not None
#                       else client.DATA_NODE_HOST)
#     nlp = DataNodeClient(host=data_node_host)
#     clinical_note = nlp.get_clinical_note(noteid)
#     utils.stdout_or_json(clinical_note, output)


# @cli.command()
# @click.option('--data_node_host',
#               help='Data node host.  If not specified, uses '
#                    'http://0.0.0.0:8080/api/v1')
# def get_health(data_node_host):
#     """Gets health of the API"""
#     data_node_host = (data_node_host if data_node_host is not None
#                       else client.DATA_NODE_HOST)
#     nlp = DataNodeClient(host=data_node_host)
#     print(nlp.get_health())


# @cli.command()
# @click.option('--output', help='Output json filepath', type=click.Path())
# @click.option('--data_node_host',
#               help='Data node host.  If not specified, uses '
#                    'http://0.0.0.0:8080/api/v1')
# def get_dates(output, data_node_host):
#     """Get all date annotations"""
#     data_node_host = (data_node_host if data_node_host is not None
#                       else client.DATA_NODE_HOST)
#     nlp = DataNodeClient(host=data_node_host)
#     dates = nlp.get_dates()
#     utils.stdout_or_json(dates, output)



"""
    NLP Sandbox Data Node API

    # Overview  The NLP Sandbox Data Node is a repository of data used to benchmark NLP Tools like the NLP Sandbox Date Annotator and Person Name Annotator.  The resources that can be stored in this Data Node and the operations supported are listed below:  - Create and manage datasets - Create and manage FHIR stores   - Store and retrieve FHIR patient profiles   - Store and retrieve clinical   notes - Create and manage annotation stores   - Store and retrieve text annotations   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import unittest
from unittest.mock import patch

import nlpsandbox
from nlpsandbox.api.health_check_api import HealthCheckApi  # noqa: E501
from nlpsandbox.api import health_check_api


class TestHealthCheckApi(unittest.TestCase):
    """HealthCheckApi unit test stubs"""

    def setUp(self):
        self.api = HealthCheckApi()  # noqa: E501
        self.nlpsandbox_api = health_check_api.HealthCheckApi()  # noqa: E501
        self.patcher = patch('nlpsandbox.api_client.ApiClient.call_api')
        self.mock_foo = self.patcher.start()
        self.patcher_f = patch('nlpsandbox.api_client.ApiClient.call_api')
        self.mock_annot = self.patcher_f.start()

    def tearDown(self):
        self.patcher.stop()

    def test_get_health_check(self):
        """Test case for get_health_check

        Get health check information  # noqa: E501
        """
        self.api.get_health_check()

    def test_get_nlpsandbox_health_check(self):
        """Test case for get_health_check

        Get health check information  # noqa: E501
        """
        self.nlpsandbox_api.get_health_check()

if __name__ == '__main__':
    unittest.main()



"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.license import License
from nlpsandbox.model.tool_type import ToolType
globals()['License'] = License
globals()['ToolType'] = ToolType
from nlpsandbox.model.tool import Tool


class TestTool(unittest.TestCase):
    """Tool unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTool(self):
        """Test Tool"""
        Tool(name="foo", version="1.0.0", license=License("apache-2.0"),
             repository="www.google.com", description="foobar",
             author="Bob", author_email="email@email.com", url="www.google.com",
             type=ToolType("tool"), api_version="1.0.0")


if __name__ == '__main__':
    unittest.main()



"""
    NLP Sandbox Date Annotator API

    # Overview The OpenAPI specification implemented by NLP Sandbox Annotators.   # noqa: E501

    The version of the OpenAPI document: 1.1.1
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nlpsandbox
from nlpsandbox.model.text_covid_symptom_annotation import TextCovidSymptomAnnotation
globals()['TextCovidSymptomAnnotation'] = TextCovidSymptomAnnotation
from nlpsandbox.model.text_covid_symptom_annotation_response import TextCovidSymptomAnnotationResponse


class TestTextCovidSymptomAnnotationResponse(unittest.TestCase):
    """TextCovidSymptomAnnotationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTextCovidSymptomAnnotationResponse(self):
        """Test TextCovidSymptomAnnotationResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TextCovidSymptomAnnotationResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""Utility functions"""
import json
import os
import re

import requests

import synapseclient


def stdout_or_json(json_dict: dict, output: str):
    """Write dict to json or stdout"""
    if output is None:
        print(json_dict)
    else:
        with open(output, 'w') as json_o:
            json.dump(json_dict, json_o)


def camelcase_to_snakecase(value):
    """Change camelcase to snakecase"""
    pattern = re.compile(r'(?<!^)(?=[A-Z])')
    return pattern.sub('_', value).lower()


def change_keys(obj, convert):
    """
    Recursivly goes through the dictionnary obj and replaces keys with the
    convert function.
    """
    if isinstance(obj, dict):
        new = {}
        for key, value in obj.items():
            new[convert(key)] = change_keys(value, convert)
    elif isinstance(obj, list):
        new = []
        for value in obj:
            new.append(change_keys(value, convert))
    else:
        return obj
    return new


def check_url(url: str):
    """Check if url is implemented

    Args:
        url: The url to check

    Raises:
        ValueError: If url is not implemented

    Examples:
        >>> check_url(url="https://www.google.com")

    """
    if not url.startswith("http"):
        url = f"http://{url}"
    response = requests.get(url)
    if not response.ok:
        raise ValueError(f"{url} not implemented")


def synapse_login():
    """Log into synapse via two methods
    a. ~/.synapseConfig
    b. SYNAPSE_USERNAME and SYNAPSE_APIKEY environmental variables
    """
    try:
        syn = synapseclient.login()
    except Exception:
        username = os.getenv("SYNAPSE_USERNAME")
        apikey = os.getenv("SYNAPSE_APIKEY")
        syn = synapseclient.login(email=username, apiKey=apikey)
    return syn



"""NLP data node client that interacts with the NLP SDK client"""
from typing import List, Iterator, Union

import requests

import nlpsandbox
from nlpsandbox.models import (
    Annotation, AnnotationStore, Dataset, Note, Tool
)
from nlpsandbox.api import (
    annotation_store_api, annotation_api, dataset_api, note_api,
    text_contact_annotation_api,
    text_covid_symptom_annotation_api,
    text_date_annotation_api,
    text_id_annotation_api,
    text_person_name_annotation_api,
    text_physical_address_annotation_api,
    tool_api,
)
from . import utils

DATA_NODE_HOST = "http://10.23.54.142/api/v1"


def list_notes(host: str, dataset_id: str, fhir_store_id: str) -> List[dict]:
    """Get all clinical notes for a dataset

    Args:
        host: Data node host IP
        dataset_id: Dataset Id
        fhir_store_id: FHIR store Id

    Yields:
        list of clinical notes.

    Examples:
        >>> notes = get_notes(host="0.0.0.0/api/v1",
        >>>                   dataset_id="awesome-dataset",
        >>>                   fhir_store_id="awesome-fhir-store")
        >>> list(notes)[0]
        {
            "id": "noteid",
            "noteType": "",
            "patientId": "patient_id",
            "text": "Example text",
            "note_name": "dataset/awesome-dataset/fhirStores/awesome-fhirstore/fhir/Note/noteid"
        }
    """
    configuration = nlpsandbox.Configuration(host=host)
    offset = 0
    limit = 10
    with nlpsandbox.ApiClient(configuration) as api_client:
        note_instance = note_api.NoteApi(api_client)
        # Obtain all clinical notes
        next_page = True
        while next_page:
            notes = note_instance.list_notes(dataset_id, fhir_store_id,
                                             offset=offset, limit=limit)
            # change from snake case to camel case
            sanitized_notes = api_client.sanitize_for_serialization(
                notes.notes
            )
            for note in sanitized_notes:
                # note_name is added for convenience for the controller as
                # it is needed to store the annotations
                note["note_name"] = f"dataset/{dataset_id}/fhirStores/{fhir_store_id}/fhir/Note/{note['identifier']}"
                yield note
            next_page = notes.links.next
            offset += limit


def get_annotation_store(host: str, dataset_id: str,
                         annotation_store_id: str,
                         create_if_missing: bool = False) -> AnnotationStore:
    """Creates an annotation store

    Args:
        host: Data node host IP
        dataset_id: Dataset Id
        annotation_store_id: Annotation store Id
        create_if_missing: Creates annotation store if the resource
                           doesn't exist

    Returns:
        Data node Annotation Store object

    Examples:
        >>> annotation = create_annotation_store(
        >>>     host="0.0.0.0/api/v1", dataset_id="awesome-dataset",
        >>>     annotation_store_id="awesome-annotation-store"
        >>> )

    """
    configuration = nlpsandbox.Configuration(host=host)
    with nlpsandbox.ApiClient(configuration) as api_client:
        annot_store_instance = annotation_store_api.AnnotationStoreApi(
            api_client
        )
        try:
            # get the annotation store
            annotation_store_obj = annot_store_instance.get_annotation_store(
                dataset_id, annotation_store_id
            )
        except nlpsandbox.rest.ApiException as err:
            if err.status == 404 and create_if_missing:
                annotation_store_obj = annot_store_instance.create_annotation_store(
                    dataset_id, annotation_store_id, body={}
                )
            else:
                raise err
    return annotation_store_obj


def get_annotation(host: str, dataset_id: str,
                   annotation_store_id: str,
                   annotation_id: str) -> Annotation:
    """Gets an annotation

    Args:
        host: Data node host IP
        dataset_id: Dataset Id
        annotation_store_id: Annotation store Id
        annotation_id: Annotation Id

    Returns:
        Data node Annotation object

    Examples:
        >>> annotation = get_annotation(
        >>>     host="0.0.0.0/api/v1", dataset_id="awesome-dataset",
        >>>     annotation_store_id="awesome-annotation-store",
        >>>     annotation_id="awesome-annotation"
        >>> )

    """
    configuration = nlpsandbox.Configuration(host=host)
    with nlpsandbox.ApiClient(configuration) as api_client:
        annot_instance = annotation_api.AnnotationApi(
            api_client
        )
        # get the annotation store
        annotation_store_obj = annot_instance.get_annotation(
            dataset_id, annotation_store_id, annotation_id
        )
    return annotation_store_obj


def _store_annotation(host: str, dataset_id: str, annotation_store_id: str,
                      annotation_id: str, annotation: dict) -> Annotation:
    """Store annotation

    Args:
        host: Data node host IP
        dataset_id: Dataset Id
        annotation_store_id: Annotation store Id
        annotation: Annotation dict

    Returns:
        Data node Annotation object

    Examples:
        >>> example_annotation = {
        >>>     "annotationSource": {
        >>>         "resourceSource": {
        >>>             "name": "name"
        >>>         }
        >>>     },
        >>>     "textDateAnnotations": [
        >>>         {
        >>>             "dateFormat": "MM/DD/YYYY",
        >>>             "length": 10,
        >>>             "start": 42,
        >>>             "text": "10/26/2020"
        >>>         },
        >>>         {
        >>>             "dateFormat": "MM/DD/YYYY",
        >>>             "length": 10,
        >>>             "start": 42,
        >>>             "text": "10/26/2020"
        >>>         }
        >>>     ],
        >>>     "textPersonNameAnnotations": [],
        >>>     "textPhysicalAddressAnnotations": []
        >>> }
        >>> annotation = store_annotation(host="0.0.0.0/api/v1",
        >>>                               dataset_id="awesome-dataset",
        >>>                               annotation_store_id="awesome-annotation-store",
        >>>                               annotation_id="awesome-id",
        >>>                               annotation=example_annotation)

    """

    configuration = nlpsandbox.Configuration(host=host)
    with nlpsandbox.ApiClient(configuration) as api_client:
        annotation_instance = annotation_api.AnnotationApi(api_client)
        new_annotation = utils.change_keys(annotation,
                                           utils.camelcase_to_snakecase)
        annotation_obj = annotation_instance.create_annotation(
            dataset_id=dataset_id,
            annotation_store_id=annotation_store_id,
            annotation_id=annotation_id,
            annotation_create_request=new_annotation,
            async_req=True
        )
    return annotation_obj.get()


def list_annotations(host: str, dataset_id: str,
                     annotation_store_id: str) -> Iterator[dict]:
    """List annotations

    Args:
        host: Data node host IP
        dataset_id: Dataset Id
        annotation_store_id: Annotation store Id

    Yields:
        Data node annotation objects

    Examples:
        >>> annotations = list_annotations(host="0.0.0.0/api/v1",
        >>>                                dataset_id="awesome-dataset",
        >>>                                annotation_store_id="awesome-annotation-store")

    """
    configuration = nlpsandbox.Configuration(host=host)
    offset = 0
    limit = 10
    with nlpsandbox.ApiClient(configuration) as api_client:
        annotation_instance = annotation_api.AnnotationApi(api_client)
        next_page = True
        while next_page:
            annotations = annotation_instance.list_annotations(
                dataset_id, annotation_store_id,
                offset=offset, limit=limit
            )
            # change from snake case to camel case
            sanitized_annotations = api_client.sanitize_for_serialization(
                annotations.annotations
            )
            for annotation in sanitized_annotations:
                yield annotation
            next_page = annotations.links.next
            offset += limit


def _annotate_person_name(api_client, text_annotation_request: dict) -> dict:
    """Annotate notes with date

    Args:
        host: Data node host IP
        text_annotation_request: Text person name annotation request

    Yields:
        Annotated notes

    Examples:
        >>> example_request = {
        >>>    "note": {
        >>>        "identifier": "note-1",
        >>>        "type": "loinc:LP29684-5",
        >>>        "patient_id": "507f1f77bcf86cd799439011",
        >>>        "text": "On 12/26/2020, Ms. Chloe Price met with Dr. Prescott."
        >>>    }
        >>> }
        >>> host = "0.0.0.0/api/v1"
        >>> configuration = nlpsandbox.Configuration(host=host)
        >>> with nlpsandbox.ApiClient(configuration) as api_client:
        >>>     annotations = _annotate_person_name(
        >>>         api_client=api_client,
        >>>         text_annotation_request=example_request
        >>>     )

    """
    # host = "http://10.23.55.45:9000/api/v1"
    api_instance = text_person_name_annotation_api.TextPersonNameAnnotationApi(api_client)
    annotations = api_instance.create_text_person_name_annotations(
        text_person_name_annotation_request=text_annotation_request
    )
    return annotations


def _annotate_physical_address(api_client, text_annotation_request: dict) -> dict:
    """Annotate notes with date

    Args:
        host: Data node host IP
        text_annotation_request: Text physical address annotation request

    Yields:
        Annotated notes

    Examples:
        >>> example_request = {
        >>>    "note": {
        >>>        "identifier": "note-1",
        >>>        "type": "loinc:LP29684-5",
        >>>        "patient_id": "507f1f77bcf86cd799439011",
        >>>        "text": "On 12/26/2020, Ms. Chloe Price met with Dr. Prescott."
        >>>    }
        >>> }
        >>> host = "0.0.0.0/api/v1"
        >>> configuration = nlpsandbox.Configuration(host=host)
        >>> with nlpsandbox.ApiClient(configuration) as api_client:
        >>>     annotations = _annotate_physical_address(
        >>>         api_client=api_client,
        >>>         text_annotation_request=example_request
        >>>     )

    """
    # host = "http://10.23.55.45:9000/api/v1"
    api_instance = text_physical_address_annotation_api.TextPhysicalAddressAnnotationApi(api_client)
    annotations = api_instance.create_text_physical_address_annotations(
        text_physical_address_annotation_request=text_annotation_request
    )
    return annotations


def _annotate_date(api_client, text_annotation_request: dict) -> dict:
    """Annotate notes with date

    Args:
        host: Data node host IP
        text_annotation_request: Text date annotation request

    Yields:
        Annotated notes

    Examples:
        >>> example_request = {
        >>>    "note": {
        >>>        "identifier": "note-1",
        >>>        "type": "loinc:LP29684-5",
        >>>        "patient_id": "507f1f77bcf86cd799439011",
        >>>        "text": "On 12/26/2020, Ms. Chloe Price met with Dr. Prescott."
        >>>    }
        >>> }
        >>> host = "0.0.0.0/api/v1"
        >>> configuration = nlpsandbox.Configuration(host=host)
        >>> with nlpsandbox.ApiClient(configuration) as api_client:
        >>>     annotations = _annotate_person(
        >>>         api_client=api_client,
        >>>         text_annotation_request=example_request
        >>> )

    """
    # host = "http://10.23.55.45:9000/api/v1"
    api_instance = text_date_annotation_api.TextDateAnnotationApi(api_client)
    annotations = api_instance.create_text_date_annotations(
        text_date_annotation_request=text_annotation_request
    )
    return annotations


def _annotate_contact(api_client, text_annotation_request: dict) -> dict:
    """Annotate notes with contact

    Args:
        host: Data node host IP
        text_annotation_request: Text contact annotation request

    Yields:
        Annotated notes

    Examples:
        >>> example_request = {
        >>>    "note": {
        >>>        "identifier": "note-1",
        >>>        "type": "loinc:LP29684-5",
        >>>        "patient_id": "507f1f77bcf86cd799439011",
        >>>        "text": "On 12/26/2020, Ms. Chloe Price met with Dr. Prescott. Her phone number is 203-555-4545."
        >>>    }
        >>> }
        >>> host = "0.0.0.0/api/v1"
        >>> configuration = nlpsandbox.Configuration(host=host)
        >>> with nlpsandbox.ApiClient(configuration) as api_client:
        >>>     annotations = _annotate_contact(
        >>>         api_client=api_client,
        >>>         text_annotation_request=example_request
        >>>     )

    """
    # host = "http://10.23.55.45:9000/api/v1"
    api_instance = text_contact_annotation_api.TextContactAnnotationApi(
        api_client
    )
    annotations = api_instance.create_text_contact_annotations(
        text_contact_annotation_request=text_annotation_request
    )
    return annotations


def _annotate_id(api_client, text_annotation_request: dict) -> dict:
    """Annotate notes with id

    Args:
        host: Data node host IP
        text_annotation_request: Text id annotation request

    Yields:
        Annotated notes

    Examples:
        >>> example_request = {
        >>>    "note": {
        >>>        "identifier": "note-1",
        >>>        "type": "loinc:LP29684-5",
        >>>        "patient_id": "507f1f77bcf86cd799439011",
        >>>        "text": "On 12/26/2020, Ms. Chloe Price met with Dr. Prescott. Her SSN is 123-45-6789."
        >>>    }
        >>> }
        >>> host = "0.0.0.0/api/v1"
        >>> configuration = nlpsandbox.Configuration(host=host)
        >>> with nlpsandbox.ApiClient(configuration) as api_client:
        >>>     annotations = _annotate_id(
        >>>         api_client=api_client,
        >>>         text_annotation_request=example_request
        >>>     )

    """
    # host = "http://10.23.55.45:9000/api/v1"
    api_instance = text_id_annotation_api.TextIdAnnotationApi(
        api_client
    )
    annotations = api_instance.create_text_id_annotations(
        text_id_annotation_request=text_annotation_request
    )
    return annotations


def _annotate_covid_symptom(api_client, text_annotation_request: dict) -> dict:
    """Annotate notes with covid symptom

    Args:
        host: Data node host IP
        text_annotation_request: Text id annotation request

    Yields:
        Annotated notes

    Examples:
        >>> example_request = {
        >>>    "note": {
        >>>        "identifier": "note-1",
        >>>        "type": "loinc:LP29684-5",
        >>>        "patient_id": "507f1f77bcf86cd799439011",
        >>>        "text": "On 12/26/2020, Ms. Chloe Price met with Dr. Prescott. She's had a dry cough for almost a week now."
        >>>    }
        >>> }
        >>> host = "0.0.0.0/api/v1"
        >>> configuration = nlpsandbox.Configuration(host=host)
        >>> with nlpsandbox.ApiClient(configuration) as api_client:
        >>>     annotations = _annotate_covid_symptom(
        >>>         api_client=api_client,
        >>>         text_annotation_request=example_request
        >>>     )

    """  # noqa: E501
    # host = "http://10.23.55.45:9000/api/v1"
    api_instance = text_covid_symptom_annotation_api.TextCovidSymptomAnnotationApi(  # noqa: E501
        api_client
    )
    annotations = api_instance.create_text_covid_symptom_annotations(
        text_covid_symptom_annotation_request=text_annotation_request
    )
    return annotations


def annotate_note(host: str, note: Union[dict, Note],
                  tool_type: str) -> dict:
    """Annotate notes

    Args:
        host: Data node host IP
        note: Clinical note
        tool_type: Type of annotator

    Yields:
        Annotated notes

    Examples:
        >>> example_note = {
        >>>    "identifier": "note-1",
        >>>    "noteType": "loinc:LP29684-5",
        >>>    "patientId": "507f1f77bcf86cd799439011",
        >>>    "text": "On 12/26/2020, Ms. Chloe Price met with Dr. Prescott."
        >>> }
        >>> annotations = annotate_note(host="0.0.0.0/api/v1",
        >>>                             note=example_note,
        >>>                             tool_type="date")

    """
    # host = "http://10.23.55.45:9000/api/v1"
    configuration = nlpsandbox.Configuration(host=host)
    # Change clinical note into text annotation request format
    if isinstance(note, Note):
        text_annotator_req = {"note": note.to_dict()}
    else:
        text_annotator_req = {
            "note": utils.change_keys(note, utils.camelcase_to_snakecase)
        }
    with nlpsandbox.ApiClient(configuration) as api_client:
        if tool_type == "nlpsandbox:date-annotator":
            annotations = _annotate_date(api_client, text_annotator_req)
        elif tool_type == "nlpsandbox:person-name-annotator":
            annotations = _annotate_person_name(api_client, text_annotator_req)
        elif tool_type == "nlpsandbox:physical-address-annotator":
            annotations = _annotate_physical_address(api_client, text_annotator_req)
        elif tool_type == "nlpsandbox:contact-annotator":
            annotations = _annotate_contact(api_client, text_annotator_req)
        elif tool_type == "nlpsandbox:id-annotator":
            annotations = _annotate_id(api_client, text_annotator_req)
        elif tool_type == "nlpsandbox:covid-symptom-annotator":
            annotations = _annotate_covid_symptom(api_client,
                                                  text_annotator_req)
        else:
            raise ValueError(f"Invalid annotator_type: {tool_type}")
        sanitized_annotations = api_client.sanitize_for_serialization(
            annotations
        )
    return sanitized_annotations


def get_tool(host: str) -> Tool:
    """Get annotater service

    Args:
        host: Annotation Service host IP

    Returns:
        Service object

    Raises:
        ValueError: If tool base URL isn't redirected to tool service endpoint

    Examples:
        >>> tool = get_tool(host="0.0.0.0/api/v1")

    """
    # host = "http://10.23.55.45:9000/api/v1"
    configuration = nlpsandbox.Configuration(host=host)
    with nlpsandbox.ApiClient(configuration) as api_client:
        tool_instance = tool_api.ToolApi(api_client)
        tool_info = tool_instance.get_tool()
    # check if tool / redirects to /tool path
    redirect_info = _get_tool_redirect(host)
    if tool_info.to_dict() != redirect_info:
        raise ValueError("Tool base URL must redirect to tool service")
    return tool_info


def list_datasets(host: str) -> List[dict]:
    """Get all datasets

    Args:
        host: Data node host IP

    Yields:
        list of datasets.

    Examples:
        >>> datasets = list_datasets(host="0.0.0.0/api/v1")
        >>> list(datasets)[0]
        >>> {
        >>>    "name": "datasets/testing"
        >>> }
    """
    configuration = nlpsandbox.Configuration(host=host)
    offset = 0
    limit = 10
    with nlpsandbox.ApiClient(configuration) as api_client:
        api_instance = dataset_api.DatasetApi(api_client)
        # Obtain all clinical notes
        next_page = True
        while next_page:
            datasets = api_instance.list_datasets(offset=offset, limit=limit)
            # change from snake case to camel case
            sanitized = api_client.sanitize_for_serialization(
                datasets.datasets
            )
            for dataset in sanitized:
                yield dataset
            next_page = datasets.links.next
            offset += limit


def _get_tool_redirect(host: str) -> Tool:
    """Make sure tool's base URL redirects to tool service

    Args:
        host: Annotation Service host IP

    Returns:
        Service object

    Examples:
        >>> tool = _get_tool_redirect(host="0.0.0.0/api/v1")

    """

    # host = "http://10.23.55.45:9000/api/v1"
    if not host.startswith("http"):
        host = f"http://{host}"
    # Remove /api/v1 string
    host = host.replace("/api/v1", '')
    response = requests.get(host)
    tool_response = utils.change_keys(response.json(),
                                      utils.camelcase_to_snakecase)
    return tool_response


def store_annotations(host: str, dataset_id: str, annotation_store_id: str,
                      annotations: dict,
                      delete_existing_annotations: bool = True):
    """Store submission annotated notes.  Delete an annotation store if
    the annotation store exists, then create a new annotation store, then
    store the annotation.

    Args:
        host: Data node host IP
        dataset_id: Dataset Id
        annotation_store_id: Annotation store Id
        annotations: Data Node Annotations
        delete_existing_annotations: To delete existing annotation store.
                                     Default is True.
    """
    configuration = nlpsandbox.Configuration(host=host)
    with nlpsandbox.ApiClient(configuration) as api_client:
        annot_store_instance = annotation_store_api.AnnotationStoreApi(
            api_client
        )
        try:
            # Always try to delete the annotation store prior to
            # storing predictions
            if delete_existing_annotations:
                annot_store_instance.delete_annotation_store(
                    dataset_id, annotation_store_id
                )
                print("Deleted existing Annotation Store")
        except nlpsandbox.rest.ApiException:
            pass
        try:
            annot_store_instance.create_annotation_store(
                dataset_id, annotation_store_id, body={}
            )
            print("Created Annotation Store")
        except nlpsandbox.rest.ApiException:
            print("Using existing Annotation Store")

    for annotation in annotations:
        annotation_id = annotation[
            'annotationSource'
        ]['resourceSource']['name'].split("/")[-1]
        _store_annotation(
            host=host,
            dataset_id=dataset_id,
            annotation_store_id=annotation_store_id,
            annotation_id=annotation_id,
            annotation=annotation
        )


def store_dataset(host: str, dataset_id: str) -> Dataset:
    """Creates a dataset"""
    configuration = nlpsandbox.Configuration(host=host)
    # Enter a context with an instance of the API client
    with nlpsandbox.ApiClient(configuration) as api_client:
        # Create an instance of the API class
        api_instance = dataset_api.DatasetApi(api_client)
        body = {}
        dataset = api_instance.create_dataset(dataset_id, body=body)
    return dataset


def delete_dataset(host: str, dataset_id: str):
    """Deletes a dataset"""
    configuration = nlpsandbox.Configuration(host=host)
    # Enter a context with an instance of the API client
    with nlpsandbox.ApiClient(configuration) as api_client:
        # Create an instance of the API class
        api_instance = dataset_api.DatasetApi(api_client)
        api_instance.delete_dataset(dataset_id)



"""
    NLP Sandbox Data Node API

    # Overview  The NLP Sandbox Data Node is a repository of data used to benchmark NLP Tools like the NLP Sandbox Date Annotator and Person Name Annotator.  The resources that can be stored in this Data Node and the operations supported are listed below:  - Create and manage datasets - Create and manage FHIR stores   - Store and retrieve FHIR patient profiles   - Store and retrieve clinical   notes - Create and manage annotation stores   - Store and retrieve text annotations   # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Contact: thomas.schaffter@sagebionetworks.org
    Generated by: https://openapi-generator.tech
"""


import unittest
from unittest.mock import patch, Mock

import nlpsandbox
from nlpsandbox.api.annotation_store_api import AnnotationStoreApi  # noqa: E501


class TestAnnotationStoreApi(unittest.TestCase):
    """AnnotationStoreApi unit test stubs"""

    def setUp(self):
        self.api = AnnotationStoreApi()  # noqa: E501
        self.patcher = patch('nlpsandbox.api_client.ApiClient.call_api')
        self.mock_foo = self.patcher.start()

    def tearDown(self):
        self.patcher.stop()

    def test_create_annotation_store(self):
        """Test case for create_annotation_store

        Create an annotation store  # noqa: E501
        """
        self.api.create_annotation_store(
            dataset_id="dataset",
            annotation_store_id="store",
            body={}
        )

    def test_delete_annotation_store(self):
        """Test case for delete_annotation_store

        Delete an annotation store  # noqa: E501
        """
        self.api.delete_annotation_store(
            dataset_id="dataset",
            annotation_store_id="store"
        )

    def test_get_annotation_store(self):
        """Test case for get_annotation_store

        Get an annotation store  # noqa: E501
        """
        self.api.get_annotation_store(
            dataset_id="dataset",
            annotation_store_id="store"
        )

    def test_list_annotation_stores(self):
        """Test case for list_annotation_stores

        List the annotation stores in a dataset  # noqa: E501
        """
        self.api.list_annotation_stores(
            dataset_id="dataset"
        )


if __name__ == '__main__':
    unittest.main()
